/* granite.h generated by valac 0.56.17, the Vala compiler, do not modify */

#ifndef __LIB_GRANITE_H__
#define __LIB_GRANITE_H__

#include <gtk/gtk.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <cairo-gobject.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <gio/gio.h>
#include <gee.h>
#include <pango/pango.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define GRANITE_STYLE_CLASS_BADGE "badge"
#define GRANITE_STYLE_CLASS_CATEGORY_EXPANDER "category-expander"
#define GRANITE_STYLE_CLASS_CONTENT_VIEW "content-view"
#define GRANITE_STYLE_CLASS_CONTENT_VIEW_WINDOW "content-view-window"
#define GRANITE_STYLE_CLASS_COMPOSITED "composited"
#define GRANITE_STYLE_CLASS_DECORATED_WINDOW "decorated-window"
#define GRANITE_STYLE_CLASS_H1_TEXT "h1"
#define GRANITE_STYLE_CLASS_H2_TEXT "h2"
#define GRANITE_STYLE_CLASS_H3_TEXT "h3"
#define GRANITE_STYLE_CLASS_HELP_BUTTON "help_button"
#define GRANITE_STYLE_CLASS_OVERLAY_BAR "overlay-bar"
#define GRANITE_STYLE_CLASS_POPOVER "popover"
#define GRANITE_STYLE_CLASS_POPOVER_BG "popover_bg"
#define GRANITE_STYLE_CLASS_SOURCE_LIST "source-list"
#define GRANITE_STYLE_CLASS_THIN_PANE_SEPARATOR "sidebar-pane-separator"
#define GRANITE_STYLE_CLASS_TITLE_TEXT "title"
#define GRANITE_STYLE_CLASS_ACCENT "accent"
#define GRANITE_STYLE_CLASS_AVATAR "avatar"
#define GRANITE_STYLE_CLASS_BACK_BUTTON "back-button"
#define GRANITE_STYLE_CLASS_CARD "card"
#define GRANITE_STYLE_CLASS_CHECKERBOARD "checkerboard"
#define GRANITE_STYLE_CLASS_COLOR_BUTTON "color-button"
#define GRANITE_STYLE_CLASS_DEFAULT_DECORATION "default-decoration"
#define GRANITE_STYLE_CLASS_H1_LABEL "h1"
#define GRANITE_STYLE_CLASS_H2_LABEL "h2"
#define GRANITE_STYLE_CLASS_H3_LABEL "h3"
#define GRANITE_STYLE_CLASS_H4_LABEL "h4"
#define GRANITE_STYLE_CLASS_KEYCAP "keycap"
#define GRANITE_STYLE_CLASS_MODE_SWITCH "mode-switch"
#define GRANITE_STYLE_CLASS_PRIMARY_LABEL "primary"
#define GRANITE_STYLE_CLASS_ROUNDED "rounded"
#define GRANITE_STYLE_CLASS_SEEKBAR "seek-bar"
#define GRANITE_STYLE_CLASS_SMALL_LABEL "small-label"
#define GRANITE_STYLE_CLASS_STORAGEBAR "storage-bar"
#define GRANITE_STYLE_CLASS_TERMINAL "terminal"
#define GRANITE_STYLE_CLASS_WELCOME "welcome"
#define GRANITE_STYLE_CLASS_WARMTH "warmth"
#define GRANITE_STYLE_CLASS_TEMPERATURE "temperature"
#define GRANITE_TRANSITION_DURATION_CLOSE 200
#define GRANITE_TRANSITION_DURATION_IN_PLACE 100
#define GRANITE_TRANSITION_DURATION_OPEN 250
#define GRANITE_TOOLTIP_SECONDARY_TEXT_MARKUP "<span weight=\"600\" size=\"smaller\" alpha=\"75%\">%s</span>"

#define GRANITE_TYPE_APPLICATION (granite_application_get_type ())
#define GRANITE_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_APPLICATION, GraniteApplication))
#define GRANITE_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_APPLICATION, GraniteApplicationClass))
#define GRANITE_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_APPLICATION))
#define GRANITE_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_APPLICATION))
#define GRANITE_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_APPLICATION, GraniteApplicationClass))

typedef struct _GraniteApplication GraniteApplication;
typedef struct _GraniteApplicationClass GraniteApplicationClass;
typedef struct _GraniteApplicationPrivate GraniteApplicationPrivate;

#define GRANITE_DRAWING_TYPE_BUFFER_SURFACE (granite_drawing_buffer_surface_get_type ())
#define GRANITE_DRAWING_BUFFER_SURFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_DRAWING_TYPE_BUFFER_SURFACE, GraniteDrawingBufferSurface))
#define GRANITE_DRAWING_BUFFER_SURFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_DRAWING_TYPE_BUFFER_SURFACE, GraniteDrawingBufferSurfaceClass))
#define GRANITE_DRAWING_IS_BUFFER_SURFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_DRAWING_TYPE_BUFFER_SURFACE))
#define GRANITE_DRAWING_IS_BUFFER_SURFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_DRAWING_TYPE_BUFFER_SURFACE))
#define GRANITE_DRAWING_BUFFER_SURFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_DRAWING_TYPE_BUFFER_SURFACE, GraniteDrawingBufferSurfaceClass))

typedef struct _GraniteDrawingBufferSurface GraniteDrawingBufferSurface;
typedef struct _GraniteDrawingBufferSurfaceClass GraniteDrawingBufferSurfaceClass;
typedef struct _GraniteDrawingBufferSurfacePrivate GraniteDrawingBufferSurfacePrivate;

#define GRANITE_DRAWING_TYPE_COLOR (granite_drawing_color_get_type ())
#define GRANITE_DRAWING_COLOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_DRAWING_TYPE_COLOR, GraniteDrawingColor))
#define GRANITE_DRAWING_COLOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_DRAWING_TYPE_COLOR, GraniteDrawingColorClass))
#define GRANITE_DRAWING_IS_COLOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_DRAWING_TYPE_COLOR))
#define GRANITE_DRAWING_IS_COLOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_DRAWING_TYPE_COLOR))
#define GRANITE_DRAWING_COLOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_DRAWING_TYPE_COLOR, GraniteDrawingColorClass))

typedef struct _GraniteDrawingColor GraniteDrawingColor;
typedef struct _GraniteDrawingColorClass GraniteDrawingColorClass;

#define GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE (granite_services_settings_serializable_get_type ())
#define GRANITE_SERVICES_SETTINGS_SERIALIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE, GraniteServicesSettingsSerializable))
#define GRANITE_SERVICES_IS_SETTINGS_SERIALIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE))
#define GRANITE_SERVICES_SETTINGS_SERIALIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRANITE_SERVICES_TYPE_SETTINGS_SERIALIZABLE, GraniteServicesSettingsSerializableIface))

typedef struct _GraniteServicesSettingsSerializable GraniteServicesSettingsSerializable;
typedef struct _GraniteServicesSettingsSerializableIface GraniteServicesSettingsSerializableIface;
typedef struct _GraniteDrawingColorPrivate GraniteDrawingColorPrivate;

#define GRANITE_DRAWING_TYPE_UTILITIES (granite_drawing_utilities_get_type ())
#define GRANITE_DRAWING_UTILITIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_DRAWING_TYPE_UTILITIES, GraniteDrawingUtilities))
#define GRANITE_DRAWING_UTILITIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_DRAWING_TYPE_UTILITIES, GraniteDrawingUtilitiesClass))
#define GRANITE_DRAWING_IS_UTILITIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_DRAWING_TYPE_UTILITIES))
#define GRANITE_DRAWING_IS_UTILITIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_DRAWING_TYPE_UTILITIES))
#define GRANITE_DRAWING_UTILITIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_DRAWING_TYPE_UTILITIES, GraniteDrawingUtilitiesClass))

typedef struct _GraniteDrawingUtilities GraniteDrawingUtilities;
typedef struct _GraniteDrawingUtilitiesClass GraniteDrawingUtilitiesClass;
typedef struct _GraniteDrawingUtilitiesPrivate GraniteDrawingUtilitiesPrivate;

#define GRANITE_SERVICES_TYPE_CONTRACT (granite_services_contract_get_type ())
#define GRANITE_SERVICES_CONTRACT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_CONTRACT, GraniteServicesContract))
#define GRANITE_SERVICES_IS_CONTRACT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_CONTRACT))
#define GRANITE_SERVICES_CONTRACT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRANITE_SERVICES_TYPE_CONTRACT, GraniteServicesContractIface))

typedef struct _GraniteServicesContract GraniteServicesContract;
typedef struct _GraniteServicesContractIface GraniteServicesContractIface;

#define GRANITE_SERVICES_TYPE_CONTRACTOR_ERROR (granite_services_contractor_error_get_type ())

#define GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY (granite_services_contractor_proxy_get_type ())
#define GRANITE_SERVICES_CONTRACTOR_PROXY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY, GraniteServicesContractorProxy))
#define GRANITE_SERVICES_CONTRACTOR_PROXY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY, GraniteServicesContractorProxyClass))
#define GRANITE_SERVICES_IS_CONTRACTOR_PROXY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY))
#define GRANITE_SERVICES_IS_CONTRACTOR_PROXY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY))
#define GRANITE_SERVICES_CONTRACTOR_PROXY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_CONTRACTOR_PROXY, GraniteServicesContractorProxyClass))

typedef struct _GraniteServicesContractorProxy GraniteServicesContractorProxy;
typedef struct _GraniteServicesContractorProxyClass GraniteServicesContractorProxyClass;
typedef struct _GraniteServicesContractorProxyPrivate GraniteServicesContractorProxyPrivate;

#define GRANITE_SERVICES_TYPE_ICON_FACTORY (granite_services_icon_factory_get_type ())
#define GRANITE_SERVICES_ICON_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_ICON_FACTORY, GraniteServicesIconFactory))
#define GRANITE_SERVICES_ICON_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_ICON_FACTORY, GraniteServicesIconFactoryClass))
#define GRANITE_SERVICES_IS_ICON_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_ICON_FACTORY))
#define GRANITE_SERVICES_IS_ICON_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_ICON_FACTORY))
#define GRANITE_SERVICES_ICON_FACTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_ICON_FACTORY, GraniteServicesIconFactoryClass))

typedef struct _GraniteServicesIconFactory GraniteServicesIconFactory;
typedef struct _GraniteServicesIconFactoryClass GraniteServicesIconFactoryClass;
typedef struct _GraniteServicesIconFactoryPrivate GraniteServicesIconFactoryPrivate;
typedef enum  {
	GRANITE_SERVICES_LOG_LEVEL_DEBUG,
	GRANITE_SERVICES_LOG_LEVEL_INFO,
	GRANITE_SERVICES_LOG_LEVEL_NOTIFY,
	GRANITE_SERVICES_LOG_LEVEL_WARN,
	GRANITE_SERVICES_LOG_LEVEL_ERROR,
	GRANITE_SERVICES_LOG_LEVEL_FATAL
} GraniteServicesLogLevel;

#define GRANITE_SERVICES_TYPE_LOG_LEVEL (granite_services_log_level_get_type ())

#define GRANITE_SERVICES_TYPE_LOGGER (granite_services_logger_get_type ())
#define GRANITE_SERVICES_LOGGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_LOGGER, GraniteServicesLogger))
#define GRANITE_SERVICES_LOGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_LOGGER, GraniteServicesLoggerClass))
#define GRANITE_SERVICES_IS_LOGGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_LOGGER))
#define GRANITE_SERVICES_IS_LOGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_LOGGER))
#define GRANITE_SERVICES_LOGGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_LOGGER, GraniteServicesLoggerClass))

typedef struct _GraniteServicesLogger GraniteServicesLogger;
typedef struct _GraniteServicesLoggerClass GraniteServicesLoggerClass;
typedef struct _GraniteServicesLoggerPrivate GraniteServicesLoggerPrivate;

#define GRANITE_SERVICES_TYPE_PATHS (granite_services_paths_get_type ())
#define GRANITE_SERVICES_PATHS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_PATHS, GraniteServicesPaths))
#define GRANITE_SERVICES_PATHS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_PATHS, GraniteServicesPathsClass))
#define GRANITE_SERVICES_IS_PATHS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_PATHS))
#define GRANITE_SERVICES_IS_PATHS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_PATHS))
#define GRANITE_SERVICES_PATHS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_PATHS, GraniteServicesPathsClass))

typedef struct _GraniteServicesPaths GraniteServicesPaths;
typedef struct _GraniteServicesPathsClass GraniteServicesPathsClass;
typedef struct _GraniteServicesPathsPrivate GraniteServicesPathsPrivate;

#define GRANITE_SERVICES_TYPE_SETTINGS (granite_services_settings_get_type ())
#define GRANITE_SERVICES_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_SETTINGS, GraniteServicesSettings))
#define GRANITE_SERVICES_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_SETTINGS, GraniteServicesSettingsClass))
#define GRANITE_SERVICES_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_SETTINGS))
#define GRANITE_SERVICES_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_SETTINGS))
#define GRANITE_SERVICES_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_SETTINGS, GraniteServicesSettingsClass))

typedef struct _GraniteServicesSettings GraniteServicesSettings;
typedef struct _GraniteServicesSettingsClass GraniteServicesSettingsClass;
typedef struct _GraniteServicesSettingsPrivate GraniteServicesSettingsPrivate;

#define GRANITE_SERVICES_TYPE_SIMPLE_COMMAND (granite_services_simple_command_get_type ())
#define GRANITE_SERVICES_SIMPLE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_SIMPLE_COMMAND, GraniteServicesSimpleCommand))
#define GRANITE_SERVICES_SIMPLE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_SIMPLE_COMMAND, GraniteServicesSimpleCommandClass))
#define GRANITE_SERVICES_IS_SIMPLE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_SIMPLE_COMMAND))
#define GRANITE_SERVICES_IS_SIMPLE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_SIMPLE_COMMAND))
#define GRANITE_SERVICES_SIMPLE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_SIMPLE_COMMAND, GraniteServicesSimpleCommandClass))

typedef struct _GraniteServicesSimpleCommand GraniteServicesSimpleCommand;
typedef struct _GraniteServicesSimpleCommandClass GraniteServicesSimpleCommandClass;
typedef struct _GraniteServicesSimpleCommandPrivate GraniteServicesSimpleCommandPrivate;

#define GRANITE_SERVICES_TYPE_SYSTEM (granite_services_system_get_type ())
#define GRANITE_SERVICES_SYSTEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_SERVICES_TYPE_SYSTEM, GraniteServicesSystem))
#define GRANITE_SERVICES_SYSTEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_SERVICES_TYPE_SYSTEM, GraniteServicesSystemClass))
#define GRANITE_SERVICES_IS_SYSTEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_SERVICES_TYPE_SYSTEM))
#define GRANITE_SERVICES_IS_SYSTEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_SERVICES_TYPE_SYSTEM))
#define GRANITE_SERVICES_SYSTEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_SERVICES_TYPE_SYSTEM, GraniteServicesSystemClass))

typedef struct _GraniteServicesSystem GraniteServicesSystem;
typedef struct _GraniteServicesSystemClass GraniteServicesSystemClass;
typedef struct _GraniteServicesSystemPrivate GraniteServicesSystemPrivate;

#define GRANITE_TYPE_SETTINGS_PAGE (granite_settings_page_get_type ())
#define GRANITE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SETTINGS_PAGE, GraniteSettingsPage))
#define GRANITE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SETTINGS_PAGE, GraniteSettingsPageClass))
#define GRANITE_IS_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SETTINGS_PAGE))
#define GRANITE_IS_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SETTINGS_PAGE))
#define GRANITE_SETTINGS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SETTINGS_PAGE, GraniteSettingsPageClass))

typedef struct _GraniteSettingsPage GraniteSettingsPage;
typedef struct _GraniteSettingsPageClass GraniteSettingsPageClass;
typedef struct _GraniteSettingsPagePrivate GraniteSettingsPagePrivate;
typedef enum  {
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_ERROR,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_OFFLINE,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_SUCCESS,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_WARNING,
	GRANITE_SETTINGS_PAGE_STATUS_TYPE_NONE
} GraniteSettingsPageStatusType;

#define GRANITE_SETTINGS_PAGE_TYPE_STATUS_TYPE (granite_settings_page_status_type_get_type ())

#define GRANITE_TYPE_SIMPLE_SETTINGS_PAGE (granite_simple_settings_page_get_type ())
#define GRANITE_SIMPLE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE, GraniteSimpleSettingsPage))
#define GRANITE_SIMPLE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE, GraniteSimpleSettingsPageClass))
#define GRANITE_IS_SIMPLE_SETTINGS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE))
#define GRANITE_IS_SIMPLE_SETTINGS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE))
#define GRANITE_SIMPLE_SETTINGS_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SIMPLE_SETTINGS_PAGE, GraniteSimpleSettingsPageClass))

typedef struct _GraniteSimpleSettingsPage GraniteSimpleSettingsPage;
typedef struct _GraniteSimpleSettingsPageClass GraniteSimpleSettingsPageClass;
typedef struct _GraniteSimpleSettingsPagePrivate GraniteSimpleSettingsPagePrivate;

#define GRANITE_TYPE_ACCEL_LABEL (granite_accel_label_get_type ())
#define GRANITE_ACCEL_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_ACCEL_LABEL, GraniteAccelLabel))
#define GRANITE_ACCEL_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_ACCEL_LABEL, GraniteAccelLabelClass))
#define GRANITE_IS_ACCEL_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_ACCEL_LABEL))
#define GRANITE_IS_ACCEL_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_ACCEL_LABEL))
#define GRANITE_ACCEL_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_ACCEL_LABEL, GraniteAccelLabelClass))

typedef struct _GraniteAccelLabel GraniteAccelLabel;
typedef struct _GraniteAccelLabelClass GraniteAccelLabelClass;
typedef struct _GraniteAccelLabelPrivate GraniteAccelLabelPrivate;

#define GRANITE_WIDGETS_TYPE_ALERT_VIEW (granite_widgets_alert_view_get_type ())
#define GRANITE_WIDGETS_ALERT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_ALERT_VIEW, GraniteWidgetsAlertView))
#define GRANITE_WIDGETS_ALERT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_ALERT_VIEW, GraniteWidgetsAlertViewClass))
#define GRANITE_WIDGETS_IS_ALERT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_ALERT_VIEW))
#define GRANITE_WIDGETS_IS_ALERT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_ALERT_VIEW))
#define GRANITE_WIDGETS_ALERT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_ALERT_VIEW, GraniteWidgetsAlertViewClass))

typedef struct _GraniteWidgetsAlertView GraniteWidgetsAlertView;
typedef struct _GraniteWidgetsAlertViewClass GraniteWidgetsAlertViewClass;
typedef struct _GraniteWidgetsAlertViewPrivate GraniteWidgetsAlertViewPrivate;

#define GRANITE_TYPE_ASYNC_IMAGE (granite_async_image_get_type ())
#define GRANITE_ASYNC_IMAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_ASYNC_IMAGE, GraniteAsyncImage))
#define GRANITE_ASYNC_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_ASYNC_IMAGE, GraniteAsyncImageClass))
#define GRANITE_IS_ASYNC_IMAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_ASYNC_IMAGE))
#define GRANITE_IS_ASYNC_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_ASYNC_IMAGE))
#define GRANITE_ASYNC_IMAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_ASYNC_IMAGE, GraniteAsyncImageClass))

typedef struct _GraniteAsyncImage GraniteAsyncImage;
typedef struct _GraniteAsyncImageClass GraniteAsyncImageClass;
typedef struct _GraniteAsyncImagePrivate GraniteAsyncImagePrivate;

#define GRANITE_WIDGETS_TYPE_AVATAR (granite_widgets_avatar_get_type ())
#define GRANITE_WIDGETS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_AVATAR, GraniteWidgetsAvatar))
#define GRANITE_WIDGETS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_AVATAR, GraniteWidgetsAvatarClass))
#define GRANITE_WIDGETS_IS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_AVATAR))
#define GRANITE_WIDGETS_IS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_AVATAR))
#define GRANITE_WIDGETS_AVATAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_AVATAR, GraniteWidgetsAvatarClass))

typedef struct _GraniteWidgetsAvatar GraniteWidgetsAvatar;
typedef struct _GraniteWidgetsAvatarClass GraniteWidgetsAvatarClass;
typedef struct _GraniteWidgetsAvatarPrivate GraniteWidgetsAvatarPrivate;

#define GRANITE_WIDGETS_TYPE_CELL_RENDERER_BADGE (granite_widgets_cell_renderer_badge_get_type ())
#define GRANITE_WIDGETS_CELL_RENDERER_BADGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_CELL_RENDERER_BADGE, GraniteWidgetsCellRendererBadge))
#define GRANITE_WIDGETS_CELL_RENDERER_BADGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_CELL_RENDERER_BADGE, GraniteWidgetsCellRendererBadgeClass))
#define GRANITE_WIDGETS_IS_CELL_RENDERER_BADGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_CELL_RENDERER_BADGE))
#define GRANITE_WIDGETS_IS_CELL_RENDERER_BADGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_CELL_RENDERER_BADGE))
#define GRANITE_WIDGETS_CELL_RENDERER_BADGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_CELL_RENDERER_BADGE, GraniteWidgetsCellRendererBadgeClass))

typedef struct _GraniteWidgetsCellRendererBadge GraniteWidgetsCellRendererBadge;
typedef struct _GraniteWidgetsCellRendererBadgeClass GraniteWidgetsCellRendererBadgeClass;
typedef struct _GraniteWidgetsCellRendererBadgePrivate GraniteWidgetsCellRendererBadgePrivate;

#define GRANITE_WIDGETS_TYPE_CELL_RENDERER_EXPANDER (granite_widgets_cell_renderer_expander_get_type ())
#define GRANITE_WIDGETS_CELL_RENDERER_EXPANDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_CELL_RENDERER_EXPANDER, GraniteWidgetsCellRendererExpander))
#define GRANITE_WIDGETS_CELL_RENDERER_EXPANDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_CELL_RENDERER_EXPANDER, GraniteWidgetsCellRendererExpanderClass))
#define GRANITE_WIDGETS_IS_CELL_RENDERER_EXPANDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_CELL_RENDERER_EXPANDER))
#define GRANITE_WIDGETS_IS_CELL_RENDERER_EXPANDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_CELL_RENDERER_EXPANDER))
#define GRANITE_WIDGETS_CELL_RENDERER_EXPANDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_CELL_RENDERER_EXPANDER, GraniteWidgetsCellRendererExpanderClass))

typedef struct _GraniteWidgetsCellRendererExpander GraniteWidgetsCellRendererExpander;
typedef struct _GraniteWidgetsCellRendererExpanderClass GraniteWidgetsCellRendererExpanderClass;
typedef struct _GraniteWidgetsCellRendererExpanderPrivate GraniteWidgetsCellRendererExpanderPrivate;
typedef enum  {
	GRANITE_COLLAPSE_MODE_NONE = 0,
	GRANITE_COLLAPSE_MODE_LEFT = 1,
	GRANITE_COLLAPSE_MODE_TOP = 1,
	GRANITE_COLLAPSE_MODE_FIRST = 1,
	GRANITE_COLLAPSE_MODE_RIGHT = 2,
	GRANITE_COLLAPSE_MODE_BOTTOM = 2,
	GRANITE_COLLAPSE_MODE_LAST = 2
} GraniteCollapseMode;

#define GRANITE_TYPE_COLLAPSE_MODE (granite_collapse_mode_get_type ())

#define GRANITE_WIDGETS_TYPE_COLLAPSIBLE_PANED (granite_widgets_collapsible_paned_get_type ())
#define GRANITE_WIDGETS_COLLAPSIBLE_PANED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_COLLAPSIBLE_PANED, GraniteWidgetsCollapsiblePaned))
#define GRANITE_WIDGETS_COLLAPSIBLE_PANED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_COLLAPSIBLE_PANED, GraniteWidgetsCollapsiblePanedClass))
#define GRANITE_WIDGETS_IS_COLLAPSIBLE_PANED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_COLLAPSIBLE_PANED))
#define GRANITE_WIDGETS_IS_COLLAPSIBLE_PANED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_COLLAPSIBLE_PANED))
#define GRANITE_WIDGETS_COLLAPSIBLE_PANED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_COLLAPSIBLE_PANED, GraniteWidgetsCollapsiblePanedClass))

typedef struct _GraniteWidgetsCollapsiblePaned GraniteWidgetsCollapsiblePaned;
typedef struct _GraniteWidgetsCollapsiblePanedClass GraniteWidgetsCollapsiblePanedClass;
typedef struct _GraniteWidgetsCollapsiblePanedPrivate GraniteWidgetsCollapsiblePanedPrivate;

#define GRANITE_WIDGETS_TYPE_COMPOSITED_WINDOW (granite_widgets_composited_window_get_type ())
#define GRANITE_WIDGETS_COMPOSITED_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_COMPOSITED_WINDOW, GraniteWidgetsCompositedWindow))
#define GRANITE_WIDGETS_COMPOSITED_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_COMPOSITED_WINDOW, GraniteWidgetsCompositedWindowClass))
#define GRANITE_WIDGETS_IS_COMPOSITED_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_COMPOSITED_WINDOW))
#define GRANITE_WIDGETS_IS_COMPOSITED_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_COMPOSITED_WINDOW))
#define GRANITE_WIDGETS_COMPOSITED_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_COMPOSITED_WINDOW, GraniteWidgetsCompositedWindowClass))

typedef struct _GraniteWidgetsCompositedWindow GraniteWidgetsCompositedWindow;
typedef struct _GraniteWidgetsCompositedWindowClass GraniteWidgetsCompositedWindowClass;
typedef struct _GraniteWidgetsCompositedWindowPrivate GraniteWidgetsCompositedWindowPrivate;

#define GRANITE_WIDGETS_TYPE_DATE_PICKER (granite_widgets_date_picker_get_type ())
#define GRANITE_WIDGETS_DATE_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_DATE_PICKER, GraniteWidgetsDatePicker))
#define GRANITE_WIDGETS_DATE_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_DATE_PICKER, GraniteWidgetsDatePickerClass))
#define GRANITE_WIDGETS_IS_DATE_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_DATE_PICKER))
#define GRANITE_WIDGETS_IS_DATE_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_DATE_PICKER))
#define GRANITE_WIDGETS_DATE_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_DATE_PICKER, GraniteWidgetsDatePickerClass))

typedef struct _GraniteWidgetsDatePicker GraniteWidgetsDatePicker;
typedef struct _GraniteWidgetsDatePickerClass GraniteWidgetsDatePickerClass;
typedef struct _GraniteWidgetsDatePickerPrivate GraniteWidgetsDatePickerPrivate;

#define GRANITE_TYPE_DIALOG (granite_dialog_get_type ())
#define GRANITE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_DIALOG, GraniteDialog))
#define GRANITE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_DIALOG, GraniteDialogClass))
#define GRANITE_IS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_DIALOG))
#define GRANITE_IS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_DIALOG))
#define GRANITE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_DIALOG, GraniteDialogClass))

typedef struct _GraniteDialog GraniteDialog;
typedef struct _GraniteDialogClass GraniteDialogClass;
typedef struct _GraniteDialogPrivate GraniteDialogPrivate;
typedef void (*GraniteWidgetsDroppedDelegate) (gpointer user_data);

#define GRANITE_WIDGETS_TYPE_TAB (granite_widgets_tab_get_type ())
#define GRANITE_WIDGETS_TAB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_TAB, GraniteWidgetsTab))
#define GRANITE_WIDGETS_TAB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_TAB, GraniteWidgetsTabClass))
#define GRANITE_WIDGETS_IS_TAB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_TAB))
#define GRANITE_WIDGETS_IS_TAB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_TAB))
#define GRANITE_WIDGETS_TAB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_TAB, GraniteWidgetsTabClass))

typedef struct _GraniteWidgetsTab GraniteWidgetsTab;
typedef struct _GraniteWidgetsTabClass GraniteWidgetsTabClass;
typedef struct _GraniteWidgetsTabPrivate GraniteWidgetsTabPrivate;

#define GRANITE_WIDGETS_TYPE_TAB_PAGE_CONTAINER (granite_widgets_tab_page_container_get_type ())
#define GRANITE_WIDGETS_TAB_PAGE_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_TAB_PAGE_CONTAINER, GraniteWidgetsTabPageContainer))
#define GRANITE_WIDGETS_TAB_PAGE_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_TAB_PAGE_CONTAINER, GraniteWidgetsTabPageContainerClass))
#define GRANITE_WIDGETS_IS_TAB_PAGE_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_TAB_PAGE_CONTAINER))
#define GRANITE_WIDGETS_IS_TAB_PAGE_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_TAB_PAGE_CONTAINER))
#define GRANITE_WIDGETS_TAB_PAGE_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_TAB_PAGE_CONTAINER, GraniteWidgetsTabPageContainerClass))

typedef struct _GraniteWidgetsTabPageContainer GraniteWidgetsTabPageContainer;
typedef struct _GraniteWidgetsTabPageContainerClass GraniteWidgetsTabPageContainerClass;

#define GRANITE_WIDGETS_TYPE_DYNAMIC_NOTEBOOK (granite_widgets_dynamic_notebook_get_type ())
#define GRANITE_WIDGETS_DYNAMIC_NOTEBOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_DYNAMIC_NOTEBOOK, GraniteWidgetsDynamicNotebook))
#define GRANITE_WIDGETS_DYNAMIC_NOTEBOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_DYNAMIC_NOTEBOOK, GraniteWidgetsDynamicNotebookClass))
#define GRANITE_WIDGETS_IS_DYNAMIC_NOTEBOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_DYNAMIC_NOTEBOOK))
#define GRANITE_WIDGETS_IS_DYNAMIC_NOTEBOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_DYNAMIC_NOTEBOOK))
#define GRANITE_WIDGETS_DYNAMIC_NOTEBOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_DYNAMIC_NOTEBOOK, GraniteWidgetsDynamicNotebookClass))

typedef struct _GraniteWidgetsDynamicNotebook GraniteWidgetsDynamicNotebook;
typedef struct _GraniteWidgetsDynamicNotebookClass GraniteWidgetsDynamicNotebookClass;
typedef struct _GraniteWidgetsDynamicNotebookPrivate GraniteWidgetsDynamicNotebookPrivate;
typedef enum  {
	GRANITE_WIDGETS_DYNAMIC_NOTEBOOK_TAB_BAR_BEHAVIOR_ALWAYS = 0,
	GRANITE_WIDGETS_DYNAMIC_NOTEBOOK_TAB_BAR_BEHAVIOR_SINGLE = 1,
	GRANITE_WIDGETS_DYNAMIC_NOTEBOOK_TAB_BAR_BEHAVIOR_NEVER = 2
} GraniteWidgetsDynamicNotebookTabBarBehavior;

#define GRANITE_WIDGETS_DYNAMIC_NOTEBOOK_TYPE_TAB_BAR_BEHAVIOR (granite_widgets_dynamic_notebook_tab_bar_behavior_get_type ())

#define GRANITE_TYPE_HEADER_LABEL (granite_header_label_get_type ())
#define GRANITE_HEADER_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_HEADER_LABEL, GraniteHeaderLabel))
#define GRANITE_HEADER_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_HEADER_LABEL, GraniteHeaderLabelClass))
#define GRANITE_IS_HEADER_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_HEADER_LABEL))
#define GRANITE_IS_HEADER_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_HEADER_LABEL))
#define GRANITE_HEADER_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_HEADER_LABEL, GraniteHeaderLabelClass))

typedef struct _GraniteHeaderLabel GraniteHeaderLabel;
typedef struct _GraniteHeaderLabelClass GraniteHeaderLabelClass;
typedef struct _GraniteHeaderLabelPrivate GraniteHeaderLabelPrivate;

#define GRANITE_TYPE_HYPER_TEXT_VIEW (granite_hyper_text_view_get_type ())
#define GRANITE_HYPER_TEXT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_HYPER_TEXT_VIEW, GraniteHyperTextView))
#define GRANITE_HYPER_TEXT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_HYPER_TEXT_VIEW, GraniteHyperTextViewClass))
#define GRANITE_IS_HYPER_TEXT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_HYPER_TEXT_VIEW))
#define GRANITE_IS_HYPER_TEXT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_HYPER_TEXT_VIEW))
#define GRANITE_HYPER_TEXT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_HYPER_TEXT_VIEW, GraniteHyperTextViewClass))

typedef struct _GraniteHyperTextView GraniteHyperTextView;
typedef struct _GraniteHyperTextViewClass GraniteHyperTextViewClass;
typedef struct _GraniteHyperTextViewPrivate GraniteHyperTextViewPrivate;

#define GRANITE_TYPE_MESSAGE_DIALOG (granite_message_dialog_get_type ())
#define GRANITE_MESSAGE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_MESSAGE_DIALOG, GraniteMessageDialog))
#define GRANITE_MESSAGE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_MESSAGE_DIALOG, GraniteMessageDialogClass))
#define GRANITE_IS_MESSAGE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_MESSAGE_DIALOG))
#define GRANITE_IS_MESSAGE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_MESSAGE_DIALOG))
#define GRANITE_MESSAGE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_MESSAGE_DIALOG, GraniteMessageDialogClass))

typedef struct _GraniteMessageDialog GraniteMessageDialog;
typedef struct _GraniteMessageDialogClass GraniteMessageDialogClass;
typedef struct _GraniteMessageDialogPrivate GraniteMessageDialogPrivate;

#define GRANITE_WIDGETS_TYPE_MODE_BUTTON (granite_widgets_mode_button_get_type ())
#define GRANITE_WIDGETS_MODE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_MODE_BUTTON, GraniteWidgetsModeButton))
#define GRANITE_WIDGETS_MODE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_MODE_BUTTON, GraniteWidgetsModeButtonClass))
#define GRANITE_WIDGETS_IS_MODE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_MODE_BUTTON))
#define GRANITE_WIDGETS_IS_MODE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_MODE_BUTTON))
#define GRANITE_WIDGETS_MODE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_MODE_BUTTON, GraniteWidgetsModeButtonClass))

typedef struct _GraniteWidgetsModeButton GraniteWidgetsModeButton;
typedef struct _GraniteWidgetsModeButtonClass GraniteWidgetsModeButtonClass;
typedef struct _GraniteWidgetsModeButtonPrivate GraniteWidgetsModeButtonPrivate;

#define GRANITE_TYPE_MODE_SWITCH (granite_mode_switch_get_type ())
#define GRANITE_MODE_SWITCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_MODE_SWITCH, GraniteModeSwitch))
#define GRANITE_MODE_SWITCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_MODE_SWITCH, GraniteModeSwitchClass))
#define GRANITE_IS_MODE_SWITCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_MODE_SWITCH))
#define GRANITE_IS_MODE_SWITCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_MODE_SWITCH))
#define GRANITE_MODE_SWITCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_MODE_SWITCH, GraniteModeSwitchClass))

typedef struct _GraniteModeSwitch GraniteModeSwitch;
typedef struct _GraniteModeSwitchClass GraniteModeSwitchClass;
typedef struct _GraniteModeSwitchPrivate GraniteModeSwitchPrivate;

#define GRANITE_WIDGETS_TYPE_OVERLAY_BAR (granite_widgets_overlay_bar_get_type ())
#define GRANITE_WIDGETS_OVERLAY_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_OVERLAY_BAR, GraniteWidgetsOverlayBar))
#define GRANITE_WIDGETS_OVERLAY_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_OVERLAY_BAR, GraniteWidgetsOverlayBarClass))
#define GRANITE_WIDGETS_IS_OVERLAY_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_OVERLAY_BAR))
#define GRANITE_WIDGETS_IS_OVERLAY_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_OVERLAY_BAR))
#define GRANITE_WIDGETS_OVERLAY_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_OVERLAY_BAR, GraniteWidgetsOverlayBarClass))

typedef struct _GraniteWidgetsOverlayBar GraniteWidgetsOverlayBar;
typedef struct _GraniteWidgetsOverlayBarClass GraniteWidgetsOverlayBarClass;
typedef struct _GraniteWidgetsOverlayBarPrivate GraniteWidgetsOverlayBarPrivate;

#define GRANITE_TYPE_SEEK_BAR (granite_seek_bar_get_type ())
#define GRANITE_SEEK_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SEEK_BAR, GraniteSeekBar))
#define GRANITE_SEEK_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SEEK_BAR, GraniteSeekBarClass))
#define GRANITE_IS_SEEK_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SEEK_BAR))
#define GRANITE_IS_SEEK_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SEEK_BAR))
#define GRANITE_SEEK_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SEEK_BAR, GraniteSeekBarClass))

typedef struct _GraniteSeekBar GraniteSeekBar;
typedef struct _GraniteSeekBarClass GraniteSeekBarClass;
typedef struct _GraniteSeekBarPrivate GraniteSeekBarPrivate;

#define GRANITE_TYPE_SETTINGS_SIDEBAR (granite_settings_sidebar_get_type ())
#define GRANITE_SETTINGS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SETTINGS_SIDEBAR, GraniteSettingsSidebar))
#define GRANITE_SETTINGS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SETTINGS_SIDEBAR, GraniteSettingsSidebarClass))
#define GRANITE_IS_SETTINGS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SETTINGS_SIDEBAR))
#define GRANITE_IS_SETTINGS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SETTINGS_SIDEBAR))
#define GRANITE_SETTINGS_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SETTINGS_SIDEBAR, GraniteSettingsSidebarClass))

typedef struct _GraniteSettingsSidebar GraniteSettingsSidebar;
typedef struct _GraniteSettingsSidebarClass GraniteSettingsSidebarClass;
typedef struct _GraniteSettingsSidebarPrivate GraniteSettingsSidebarPrivate;

#define GRANITE_TYPE_SETTINGS (granite_settings_get_type ())
#define GRANITE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SETTINGS, GraniteSettings))
#define GRANITE_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SETTINGS, GraniteSettingsClass))
#define GRANITE_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SETTINGS))
#define GRANITE_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SETTINGS))
#define GRANITE_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SETTINGS, GraniteSettingsClass))

typedef struct _GraniteSettings GraniteSettings;
typedef struct _GraniteSettingsClass GraniteSettingsClass;
typedef struct _GraniteSettingsPrivate GraniteSettingsPrivate;
typedef enum  {
	GRANITE_SETTINGS_COLOR_SCHEME_NO_PREFERENCE,
	GRANITE_SETTINGS_COLOR_SCHEME_DARK,
	GRANITE_SETTINGS_COLOR_SCHEME_LIGHT
} GraniteSettingsColorScheme;

#define GRANITE_SETTINGS_TYPE_COLOR_SCHEME (granite_settings_color_scheme_get_type ())

#define GRANITE_WIDGETS_TYPE_SOURCE_LIST_SORTABLE (granite_widgets_source_list_sortable_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_SORTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_SORTABLE, GraniteWidgetsSourceListSortable))
#define GRANITE_WIDGETS_IS_SOURCE_LIST_SORTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_SORTABLE))
#define GRANITE_WIDGETS_SOURCE_LIST_SORTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_SORTABLE, GraniteWidgetsSourceListSortableIface))

typedef struct _GraniteWidgetsSourceListSortable GraniteWidgetsSourceListSortable;
typedef struct _GraniteWidgetsSourceListSortableIface GraniteWidgetsSourceListSortableIface;

#define GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM (granite_widgets_source_list_item_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, GraniteWidgetsSourceListItem))
#define GRANITE_WIDGETS_SOURCE_LIST_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, GraniteWidgetsSourceListItemClass))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM))
#define GRANITE_WIDGETS_SOURCE_LIST_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_ITEM, GraniteWidgetsSourceListItemClass))

typedef struct _GraniteWidgetsSourceListItem GraniteWidgetsSourceListItem;
typedef struct _GraniteWidgetsSourceListItemClass GraniteWidgetsSourceListItemClass;

#define GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM (granite_widgets_source_list_expandable_item_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, GraniteWidgetsSourceListExpandableItem))
#define GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, GraniteWidgetsSourceListExpandableItemClass))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM))
#define GRANITE_WIDGETS_SOURCE_LIST_IS_EXPANDABLE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM))
#define GRANITE_WIDGETS_SOURCE_LIST_EXPANDABLE_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_SOURCE_LIST_TYPE_EXPANDABLE_ITEM, GraniteWidgetsSourceListExpandableItemClass))

typedef struct _GraniteWidgetsSourceListExpandableItem GraniteWidgetsSourceListExpandableItem;
typedef struct _GraniteWidgetsSourceListExpandableItemClass GraniteWidgetsSourceListExpandableItemClass;

#define GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_SOURCE (granite_widgets_source_list_drag_source_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_DRAG_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_SOURCE, GraniteWidgetsSourceListDragSource))
#define GRANITE_WIDGETS_IS_SOURCE_LIST_DRAG_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_SOURCE))
#define GRANITE_WIDGETS_SOURCE_LIST_DRAG_SOURCE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_SOURCE, GraniteWidgetsSourceListDragSourceIface))

typedef struct _GraniteWidgetsSourceListDragSource GraniteWidgetsSourceListDragSource;
typedef struct _GraniteWidgetsSourceListDragSourceIface GraniteWidgetsSourceListDragSourceIface;

#define GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_DEST (granite_widgets_source_list_drag_dest_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST_DRAG_DEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_DEST, GraniteWidgetsSourceListDragDest))
#define GRANITE_WIDGETS_IS_SOURCE_LIST_DRAG_DEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_DEST))
#define GRANITE_WIDGETS_SOURCE_LIST_DRAG_DEST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST_DRAG_DEST, GraniteWidgetsSourceListDragDestIface))

typedef struct _GraniteWidgetsSourceListDragDest GraniteWidgetsSourceListDragDest;
typedef struct _GraniteWidgetsSourceListDragDestIface GraniteWidgetsSourceListDragDestIface;

#define GRANITE_WIDGETS_TYPE_SOURCE_LIST (granite_widgets_source_list_get_type ())
#define GRANITE_WIDGETS_SOURCE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST, GraniteWidgetsSourceList))
#define GRANITE_WIDGETS_SOURCE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_SOURCE_LIST, GraniteWidgetsSourceListClass))
#define GRANITE_WIDGETS_IS_SOURCE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST))
#define GRANITE_WIDGETS_IS_SOURCE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_SOURCE_LIST))
#define GRANITE_WIDGETS_SOURCE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_SOURCE_LIST, GraniteWidgetsSourceListClass))

typedef struct _GraniteWidgetsSourceList GraniteWidgetsSourceList;
typedef struct _GraniteWidgetsSourceListClass GraniteWidgetsSourceListClass;
typedef struct _GraniteWidgetsSourceListPrivate GraniteWidgetsSourceListPrivate;
typedef gboolean (*GraniteWidgetsSourceListVisibleFunc) (GraniteWidgetsSourceListItem* item, gpointer user_data);
typedef struct _GraniteWidgetsSourceListItemPrivate GraniteWidgetsSourceListItemPrivate;
typedef struct _GraniteWidgetsSourceListExpandableItemPrivate GraniteWidgetsSourceListExpandableItemPrivate;

#define GRANITE_WIDGETS_TYPE_STORAGE_BAR (granite_widgets_storage_bar_get_type ())
#define GRANITE_WIDGETS_STORAGE_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_STORAGE_BAR, GraniteWidgetsStorageBar))
#define GRANITE_WIDGETS_STORAGE_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_STORAGE_BAR, GraniteWidgetsStorageBarClass))
#define GRANITE_WIDGETS_IS_STORAGE_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_STORAGE_BAR))
#define GRANITE_WIDGETS_IS_STORAGE_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_STORAGE_BAR))
#define GRANITE_WIDGETS_STORAGE_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_STORAGE_BAR, GraniteWidgetsStorageBarClass))

typedef struct _GraniteWidgetsStorageBar GraniteWidgetsStorageBar;
typedef struct _GraniteWidgetsStorageBarClass GraniteWidgetsStorageBarClass;
typedef struct _GraniteWidgetsStorageBarPrivate GraniteWidgetsStorageBarPrivate;
typedef enum  {
	GRANITE_WIDGETS_STORAGE_BAR_ITEM_DESCRIPTION_OTHER,
	GRANITE_WIDGETS_STORAGE_BAR_ITEM_DESCRIPTION_AUDIO,
	GRANITE_WIDGETS_STORAGE_BAR_ITEM_DESCRIPTION_VIDEO,
	GRANITE_WIDGETS_STORAGE_BAR_ITEM_DESCRIPTION_PHOTO,
	GRANITE_WIDGETS_STORAGE_BAR_ITEM_DESCRIPTION_APP,
	GRANITE_WIDGETS_STORAGE_BAR_ITEM_DESCRIPTION_FILES = GRANITE_WIDGETS_STORAGE_BAR_ITEM_DESCRIPTION_OTHER
} GraniteWidgetsStorageBarItemDescription;

#define GRANITE_WIDGETS_STORAGE_BAR_TYPE_ITEM_DESCRIPTION (granite_widgets_storage_bar_item_description_get_type ())

#define GRANITE_TYPE_SWITCH_MODEL_BUTTON (granite_switch_model_button_get_type ())
#define GRANITE_SWITCH_MODEL_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_SWITCH_MODEL_BUTTON, GraniteSwitchModelButton))
#define GRANITE_SWITCH_MODEL_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_SWITCH_MODEL_BUTTON, GraniteSwitchModelButtonClass))
#define GRANITE_IS_SWITCH_MODEL_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_SWITCH_MODEL_BUTTON))
#define GRANITE_IS_SWITCH_MODEL_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_SWITCH_MODEL_BUTTON))
#define GRANITE_SWITCH_MODEL_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_SWITCH_MODEL_BUTTON, GraniteSwitchModelButtonClass))

typedef struct _GraniteSwitchModelButton GraniteSwitchModelButton;
typedef struct _GraniteSwitchModelButtonClass GraniteSwitchModelButtonClass;
typedef struct _GraniteSwitchModelButtonPrivate GraniteSwitchModelButtonPrivate;

#define GRANITE_WIDGETS_TYPE_TIME_PICKER (granite_widgets_time_picker_get_type ())
#define GRANITE_WIDGETS_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_TIME_PICKER, GraniteWidgetsTimePicker))
#define GRANITE_WIDGETS_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_TIME_PICKER, GraniteWidgetsTimePickerClass))
#define GRANITE_WIDGETS_IS_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_TIME_PICKER))
#define GRANITE_WIDGETS_IS_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_TIME_PICKER))
#define GRANITE_WIDGETS_TIME_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_TIME_PICKER, GraniteWidgetsTimePickerClass))

typedef struct _GraniteWidgetsTimePicker GraniteWidgetsTimePicker;
typedef struct _GraniteWidgetsTimePickerClass GraniteWidgetsTimePickerClass;
typedef struct _GraniteWidgetsTimePickerPrivate GraniteWidgetsTimePickerPrivate;

#define GRANITE_WIDGETS_TYPE_TOAST (granite_widgets_toast_get_type ())
#define GRANITE_WIDGETS_TOAST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_TOAST, GraniteWidgetsToast))
#define GRANITE_WIDGETS_TOAST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_TOAST, GraniteWidgetsToastClass))
#define GRANITE_WIDGETS_IS_TOAST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_TOAST))
#define GRANITE_WIDGETS_IS_TOAST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_TOAST))
#define GRANITE_WIDGETS_TOAST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_TOAST, GraniteWidgetsToastClass))

typedef struct _GraniteWidgetsToast GraniteWidgetsToast;
typedef struct _GraniteWidgetsToastClass GraniteWidgetsToastClass;
typedef struct _GraniteWidgetsToastPrivate GraniteWidgetsToastPrivate;
typedef enum  {
	GRANITE_TEXT_STYLE_TITLE,
	GRANITE_TEXT_STYLE_H1,
	GRANITE_TEXT_STYLE_H2,
	GRANITE_TEXT_STYLE_H3
} GraniteTextStyle G_GNUC_DEPRECATED ;

#define GRANITE_TYPE_TEXT_STYLE (granite_text_style_get_type ())
typedef enum  {
	GRANITE_CLOSE_BUTTON_POSITION_LEFT,
	GRANITE_CLOSE_BUTTON_POSITION_RIGHT
} GraniteCloseButtonPosition;

#define GRANITE_TYPE_CLOSE_BUTTON_POSITION (granite_close_button_position_get_type ())

#define GRANITE_TYPE_VALIDATED_ENTRY (granite_validated_entry_get_type ())
#define GRANITE_VALIDATED_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_TYPE_VALIDATED_ENTRY, GraniteValidatedEntry))
#define GRANITE_VALIDATED_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_TYPE_VALIDATED_ENTRY, GraniteValidatedEntryClass))
#define GRANITE_IS_VALIDATED_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_TYPE_VALIDATED_ENTRY))
#define GRANITE_IS_VALIDATED_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_TYPE_VALIDATED_ENTRY))
#define GRANITE_VALIDATED_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_TYPE_VALIDATED_ENTRY, GraniteValidatedEntryClass))

typedef struct _GraniteValidatedEntry GraniteValidatedEntry;
typedef struct _GraniteValidatedEntryClass GraniteValidatedEntryClass;
typedef struct _GraniteValidatedEntryPrivate GraniteValidatedEntryPrivate;

#define GRANITE_WIDGETS_TYPE_WELCOME_BUTTON (granite_widgets_welcome_button_get_type ())
#define GRANITE_WIDGETS_WELCOME_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_WELCOME_BUTTON, GraniteWidgetsWelcomeButton))
#define GRANITE_WIDGETS_WELCOME_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_WELCOME_BUTTON, GraniteWidgetsWelcomeButtonClass))
#define GRANITE_WIDGETS_IS_WELCOME_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_WELCOME_BUTTON))
#define GRANITE_WIDGETS_IS_WELCOME_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_WELCOME_BUTTON))
#define GRANITE_WIDGETS_WELCOME_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_WELCOME_BUTTON, GraniteWidgetsWelcomeButtonClass))

typedef struct _GraniteWidgetsWelcomeButton GraniteWidgetsWelcomeButton;
typedef struct _GraniteWidgetsWelcomeButtonClass GraniteWidgetsWelcomeButtonClass;
typedef struct _GraniteWidgetsWelcomeButtonPrivate GraniteWidgetsWelcomeButtonPrivate;

#define GRANITE_WIDGETS_TYPE_WELCOME (granite_widgets_welcome_get_type ())
#define GRANITE_WIDGETS_WELCOME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRANITE_WIDGETS_TYPE_WELCOME, GraniteWidgetsWelcome))
#define GRANITE_WIDGETS_WELCOME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRANITE_WIDGETS_TYPE_WELCOME, GraniteWidgetsWelcomeClass))
#define GRANITE_WIDGETS_IS_WELCOME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRANITE_WIDGETS_TYPE_WELCOME))
#define GRANITE_WIDGETS_IS_WELCOME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRANITE_WIDGETS_TYPE_WELCOME))
#define GRANITE_WIDGETS_WELCOME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRANITE_WIDGETS_TYPE_WELCOME, GraniteWidgetsWelcomeClass))

typedef struct _GraniteWidgetsWelcome GraniteWidgetsWelcome;
typedef struct _GraniteWidgetsWelcomeClass GraniteWidgetsWelcomeClass;
typedef struct _GraniteWidgetsWelcomePrivate GraniteWidgetsWelcomePrivate;

struct _GraniteApplication {
	GtkApplication parent_instance;
	gchar* build_data_dir;
	gchar* build_pkg_data_dir;
	gchar* build_release_name;
	gchar* build_version;
	gchar* build_version_info;
	gchar* program_name;
	gchar* exec_name;
	gchar* app_copyright G_GNUC_DEPRECATED ;
	gchar* app_years G_GNUC_DEPRECATED ;
	gchar* app_icon G_GNUC_DEPRECATED ;
	gchar* app_launcher;
	gchar* main_url G_GNUC_DEPRECATED ;
	gchar* bug_url G_GNUC_DEPRECATED ;
	gchar* help_url G_GNUC_DEPRECATED ;
	gchar* translate_url G_GNUC_DEPRECATED ;
	gchar** about_authors G_GNUC_DEPRECATED ;
	gint about_authors_length1;
	gchar** about_documenters G_GNUC_DEPRECATED ;
	gint about_documenters_length1;
	gchar** about_artists G_GNUC_DEPRECATED ;
	gint about_artists_length1;
	gchar* about_comments G_GNUC_DEPRECATED ;
	gchar* about_translators G_GNUC_DEPRECATED ;
	gchar* about_license G_GNUC_DEPRECATED ;
	GtkLicense about_license_type G_GNUC_DEPRECATED ;
	GraniteApplicationPrivate * priv;
};

struct _GraniteApplicationClass {
	GtkApplicationClass parent_class;
	void (*set_options) (GraniteApplication* self);
};

struct _GraniteDrawingBufferSurface {
	GObject parent_instance;
	GraniteDrawingBufferSurfacePrivate * priv;
};

struct _GraniteDrawingBufferSurfaceClass {
	GObjectClass parent_class;
};

struct _GraniteServicesSettingsSerializableIface {
	GTypeInterface parent_iface;
	gchar* (*settings_serialize) (GraniteServicesSettingsSerializable* self);
	void (*settings_deserialize) (GraniteServicesSettingsSerializable* self, const gchar* s);
};

struct _GraniteDrawingColor {
	GObject parent_instance;
	gdouble R;
	gdouble G;
	gdouble B;
	gdouble A;
	GraniteDrawingColorPrivate * priv;
};

struct _GraniteDrawingColorClass {
	GObjectClass parent_class;
};

struct _GraniteDrawingUtilities {
	GObject parent_instance;
	GraniteDrawingUtilitiesPrivate * priv;
};

struct _GraniteDrawingUtilitiesClass {
	GObjectClass parent_class;
};

struct _GraniteServicesContractIface {
	GTypeInterface parent_iface;
	gchar* (*get_display_name) (GraniteServicesContract* self);
	gchar* (*get_description) (GraniteServicesContract* self);
	GIcon* (*get_icon) (GraniteServicesContract* self);
	void (*execute_with_file) (GraniteServicesContract* self, GFile* file, GError** error);
	void (*execute_with_files) (GraniteServicesContract* self, GFile** files, gint files_length1, GError** error);
};

typedef enum  {
	GRANITE_SERVICES_CONTRACTOR_ERROR_SERVICE_NOT_AVAILABLE
} GraniteServicesContractorError;
#define GRANITE_SERVICES_CONTRACTOR_ERROR granite_services_contractor_error_quark ()

struct _GraniteServicesContractorProxy {
	GObject parent_instance;
	GraniteServicesContractorProxyPrivate * priv;
};

struct _GraniteServicesContractorProxyClass {
	GObjectClass parent_class;
};

struct _GraniteServicesIconFactory {
	GObject parent_instance;
	GraniteServicesIconFactoryPrivate * priv;
};

struct _GraniteServicesIconFactoryClass {
	GObjectClass parent_class;
};

struct _GraniteServicesLogger {
	GObject parent_instance;
	GraniteServicesLoggerPrivate * priv;
};

struct _GraniteServicesLoggerClass {
	GObjectClass parent_class;
};

struct _GraniteServicesPaths {
	GObject parent_instance;
	GraniteServicesPathsPrivate * priv;
};

struct _GraniteServicesPathsClass {
	GObjectClass parent_class;
};

struct _GraniteServicesSettings {
	GObject parent_instance;
	GraniteServicesSettingsPrivate * priv;
};

struct _GraniteServicesSettingsClass {
	GObjectClass parent_class;
	void (*verify) (GraniteServicesSettings* self, const gchar* key);
};

struct _GraniteServicesSimpleCommand {
	GObject parent_instance;
	gchar* standard_output_str;
	gchar* error_output_str;
	gchar* output_str;
	GraniteServicesSimpleCommandPrivate * priv;
};

struct _GraniteServicesSimpleCommandClass {
	GObjectClass parent_class;
};

struct _GraniteServicesSystem {
	GObject parent_instance;
	GraniteServicesSystemPrivate * priv;
};

struct _GraniteServicesSystemClass {
	GObjectClass parent_class;
};

struct _GraniteSettingsPage {
	GtkScrolledWindow parent_instance;
	gchar* _icon_name;
	gchar* _title;
	GraniteSettingsPagePrivate * priv;
};

struct _GraniteSettingsPageClass {
	GtkScrolledWindowClass parent_class;
};

struct _GraniteSimpleSettingsPage {
	GraniteSettingsPage parent_instance;
	GraniteSimpleSettingsPagePrivate * priv;
};

struct _GraniteSimpleSettingsPageClass {
	GraniteSettingsPageClass parent_class;
};

struct _GraniteAccelLabel {
	GtkGrid parent_instance;
	GraniteAccelLabelPrivate * priv;
};

struct _GraniteAccelLabelClass {
	GtkGridClass parent_class;
};

struct _GraniteWidgetsAlertView {
	GtkGrid parent_instance;
	GraniteWidgetsAlertViewPrivate * priv;
};

struct _GraniteWidgetsAlertViewClass {
	GtkGridClass parent_class;
};

struct _GraniteAsyncImage {
	GtkImage parent_instance;
	GraniteAsyncImagePrivate * priv;
};

struct _GraniteAsyncImageClass {
	GtkImageClass parent_class;
};

struct _GraniteWidgetsAvatar {
	GtkEventBox parent_instance;
	GraniteWidgetsAvatarPrivate * priv;
};

struct _GraniteWidgetsAvatarClass {
	GtkEventBoxClass parent_class;
};

struct _GraniteWidgetsCellRendererBadge {
	GtkCellRenderer parent_instance;
	GraniteWidgetsCellRendererBadgePrivate * priv;
};

struct _GraniteWidgetsCellRendererBadgeClass {
	GtkCellRendererClass parent_class;
};

struct _GraniteWidgetsCellRendererExpander {
	GtkCellRenderer parent_instance;
	GraniteWidgetsCellRendererExpanderPrivate * priv;
};

struct _GraniteWidgetsCellRendererExpanderClass {
	GtkCellRendererClass parent_class;
	gint (*get_arrow_size) (GraniteWidgetsCellRendererExpander* self, GtkWidget* widget);
};

struct _GraniteWidgetsCollapsiblePaned {
	GtkPaned parent_instance;
	GraniteWidgetsCollapsiblePanedPrivate * priv;
};

struct _GraniteWidgetsCollapsiblePanedClass {
	GtkPanedClass parent_class;
};

struct _GraniteWidgetsCompositedWindow {
	GtkWindow parent_instance;
	GraniteWidgetsCompositedWindowPrivate * priv;
};

struct _GraniteWidgetsCompositedWindowClass {
	GtkWindowClass parent_class;
};

struct _GraniteWidgetsDatePicker {
	GtkEntry parent_instance;
	GtkEventBox* dropdown;
	GtkCalendar* calendar;
	GraniteWidgetsDatePickerPrivate * priv;
};

struct _GraniteWidgetsDatePickerClass {
	GtkEntryClass parent_class;
	void (*position_dropdown) (GraniteWidgetsDatePicker* self, GdkRectangle* rect);
};

struct _GraniteDialog {
	GtkDialog parent_instance;
	GraniteDialogPrivate * priv;
};

struct _GraniteDialogClass {
	GtkDialogClass parent_class;
};

struct _GraniteWidgetsTab {
	GtkEventBox parent_instance;
	GraniteWidgetsDroppedDelegate dropped_callback;
	gpointer dropped_callback_target;
	GDestroyNotify dropped_callback_target_destroy_notify;
	GraniteWidgetsTabPageContainer* page_container;
	GtkImage* _icon;
	GtkMenuItem* new_window_m;
	GtkMenuItem* duplicate_m;
	GtkMenuItem* pin_m;
	GraniteWidgetsTabPrivate * priv;
};

struct _GraniteWidgetsTabClass {
	GtkEventBoxClass parent_class;
};

struct _GraniteWidgetsDynamicNotebook {
	GtkEventBox parent_instance;
	GraniteWidgetsDynamicNotebookPrivate * priv;
};

struct _GraniteWidgetsDynamicNotebookClass {
	GtkEventBoxClass parent_class;
};

struct _GraniteHeaderLabel {
	GtkLabel parent_instance;
	GraniteHeaderLabelPrivate * priv;
};

struct _GraniteHeaderLabelClass {
	GtkLabelClass parent_class;
};

struct _GraniteHyperTextView {
	GtkTextView parent_instance;
	GraniteHyperTextViewPrivate * priv;
};

struct _GraniteHyperTextViewClass {
	GtkTextViewClass parent_class;
};

struct _GraniteMessageDialog {
	GraniteDialog parent_instance;
	GraniteMessageDialogPrivate * priv;
};

struct _GraniteMessageDialogClass {
	GraniteDialogClass parent_class;
};

struct _GraniteWidgetsModeButton {
	GtkBox parent_instance;
	GraniteWidgetsModeButtonPrivate * priv;
};

struct _GraniteWidgetsModeButtonClass {
	GtkBoxClass parent_class;
};

struct _GraniteModeSwitch {
	GtkGrid parent_instance;
	GraniteModeSwitchPrivate * priv;
};

struct _GraniteModeSwitchClass {
	GtkGridClass parent_class;
};

struct _GraniteWidgetsOverlayBar {
	GtkEventBox parent_instance;
	GraniteWidgetsOverlayBarPrivate * priv;
};

struct _GraniteWidgetsOverlayBarClass {
	GtkEventBoxClass parent_class;
};

struct _GraniteSeekBar {
	GtkGrid parent_instance;
	GraniteSeekBarPrivate * priv;
};

struct _GraniteSeekBarClass {
	GtkGridClass parent_class;
};

struct _GraniteSettingsSidebar {
	GtkScrolledWindow parent_instance;
	GraniteSettingsSidebarPrivate * priv;
};

struct _GraniteSettingsSidebarClass {
	GtkScrolledWindowClass parent_class;
};

struct _GraniteSettings {
	GObject parent_instance;
	GraniteSettingsPrivate * priv;
};

struct _GraniteSettingsClass {
	GObjectClass parent_class;
};

struct _GraniteWidgetsSourceListSortableIface {
	GTypeInterface parent_iface;
	gboolean (*allow_dnd_sorting) (GraniteWidgetsSourceListSortable* self);
	gint (*compare) (GraniteWidgetsSourceListSortable* self, GraniteWidgetsSourceListItem* a, GraniteWidgetsSourceListItem* b);
};

struct _GraniteWidgetsSourceListDragSourceIface {
	GTypeInterface parent_iface;
	gboolean (*draggable) (GraniteWidgetsSourceListDragSource* self);
	void (*prepare_selection_data) (GraniteWidgetsSourceListDragSource* self, GtkSelectionData* selection_data);
};

struct _GraniteWidgetsSourceListDragDestIface {
	GTypeInterface parent_iface;
	gboolean (*data_drop_possible) (GraniteWidgetsSourceListDragDest* self, GdkDragContext* context, GtkSelectionData* data);
	GdkDragAction (*data_received) (GraniteWidgetsSourceListDragDest* self, GdkDragContext* context, GtkSelectionData* data);
};

struct _GraniteWidgetsSourceList {
	GtkScrolledWindow parent_instance;
	GraniteWidgetsSourceListPrivate * priv;
};

struct _GraniteWidgetsSourceListClass {
	GtkScrolledWindowClass parent_class;
	void (*item_selected) (GraniteWidgetsSourceList* self, GraniteWidgetsSourceListItem* item);
};

struct _GraniteWidgetsSourceListItem {
	GObject parent_instance;
	GraniteWidgetsSourceListItemPrivate * priv;
};

struct _GraniteWidgetsSourceListItemClass {
	GObjectClass parent_class;
	void (*edited) (GraniteWidgetsSourceListItem* self, const gchar* new_name);
	void (*action_activated) (GraniteWidgetsSourceListItem* self);
	void (*activated) (GraniteWidgetsSourceListItem* self);
	GtkMenu* (*get_context_menu) (GraniteWidgetsSourceListItem* self);
};

struct _GraniteWidgetsSourceListExpandableItem {
	GraniteWidgetsSourceListItem parent_instance;
	GraniteWidgetsSourceListExpandableItemPrivate * priv;
};

struct _GraniteWidgetsSourceListExpandableItemClass {
	GraniteWidgetsSourceListItemClass parent_class;
	void (*toggled) (GraniteWidgetsSourceListExpandableItem* self);
};

struct _GraniteWidgetsStorageBar {
	GtkBox parent_instance;
	GraniteWidgetsStorageBarPrivate * priv;
};

struct _GraniteWidgetsStorageBarClass {
	GtkBoxClass parent_class;
};

struct _GraniteSwitchModelButton {
	GtkToggleButton parent_instance;
	GraniteSwitchModelButtonPrivate * priv;
};

struct _GraniteSwitchModelButtonClass {
	GtkToggleButtonClass parent_class;
};

struct _GraniteWidgetsTimePicker {
	GtkEntry parent_instance;
	GraniteWidgetsTimePickerPrivate * priv;
};

struct _GraniteWidgetsTimePickerClass {
	GtkEntryClass parent_class;
	void (*position_dropdown) (GraniteWidgetsTimePicker* self, gint* x, gint* y) G_GNUC_DEPRECATED ;
};

struct _GraniteWidgetsToast {
	GtkRevealer parent_instance;
	GraniteWidgetsToastPrivate * priv;
};

struct _GraniteWidgetsToastClass {
	GtkRevealerClass parent_class;
};

struct _GraniteValidatedEntry {
	GtkEntry parent_instance;
	GraniteValidatedEntryPrivate * priv;
};

struct _GraniteValidatedEntryClass {
	GtkEntryClass parent_class;
};

struct _GraniteWidgetsWelcomeButton {
	GtkButton parent_instance;
	GraniteWidgetsWelcomeButtonPrivate * priv;
};

struct _GraniteWidgetsWelcomeButtonClass {
	GtkButtonClass parent_class;
};

struct _GraniteWidgetsWelcome {
	GtkEventBox parent_instance;
	GList* children;
	GtkGrid* options;
	GraniteWidgetsWelcomePrivate * priv;
};

struct _GraniteWidgetsWelcomeClass {
	GtkEventBoxClass parent_class;
};

VALA_EXTERN GType granite_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteApplication, g_object_unref)
VALA_EXTERN GraniteApplication* granite_application_construct (GType object_type);
VALA_EXTERN gint granite_application_run (GraniteApplication* self,
                              gchar** args,
                              gint args_length1);
VALA_EXTERN gboolean granite_application_DEBUG;
VALA_EXTERN void granite_application_set_options (GraniteApplication* self);
VALA_EXTERN gchar* granite_date_time_get_default_time_format (gboolean is_12h,
                                                  gboolean with_second);
VALA_EXTERN gchar* granite_date_time_get_relative_datetime (GDateTime* date_time);
VALA_EXTERN gboolean granite_date_time_is_same_day (GDateTime* day1,
                                        GDateTime* day2);
VALA_EXTERN gchar* granite_date_time_get_default_date_format (gboolean with_weekday,
                                                  gboolean with_day,
                                                  gboolean with_year);
VALA_EXTERN gchar* granite_date_time_seconds_to_time (gint seconds);
VALA_EXTERN GType granite_drawing_buffer_surface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteDrawingBufferSurface, g_object_unref)
VALA_EXTERN cairo_surface_t* granite_drawing_buffer_surface_get_surface (GraniteDrawingBufferSurface* self);
VALA_EXTERN gint granite_drawing_buffer_surface_get_width (GraniteDrawingBufferSurface* self);
VALA_EXTERN gint granite_drawing_buffer_surface_get_height (GraniteDrawingBufferSurface* self);
VALA_EXTERN cairo_t* granite_drawing_buffer_surface_get_context (GraniteDrawingBufferSurface* self);
VALA_EXTERN GraniteDrawingBufferSurface* granite_drawing_buffer_surface_new (gint width,
                                                                 gint height);
VALA_EXTERN GraniteDrawingBufferSurface* granite_drawing_buffer_surface_construct (GType object_type,
                                                                       gint width,
                                                                       gint height);
VALA_EXTERN GraniteDrawingBufferSurface* granite_drawing_buffer_surface_new_with_surface (gint width,
                                                                              gint height,
                                                                              cairo_surface_t* model);
VALA_EXTERN GraniteDrawingBufferSurface* granite_drawing_buffer_surface_construct_with_surface (GType object_type,
                                                                                    gint width,
                                                                                    gint height,
                                                                                    cairo_surface_t* model);
VALA_EXTERN GraniteDrawingBufferSurface* granite_drawing_buffer_surface_new_with_buffer_surface (gint width,
                                                                                     gint height,
                                                                                     GraniteDrawingBufferSurface* model);
VALA_EXTERN GraniteDrawingBufferSurface* granite_drawing_buffer_surface_construct_with_buffer_surface (GType object_type,
                                                                                           gint width,
                                                                                           gint height,
                                                                                           GraniteDrawingBufferSurface* model);
VALA_EXTERN void granite_drawing_buffer_surface_clear (GraniteDrawingBufferSurface* self);
VALA_EXTERN GdkPixbuf* granite_drawing_buffer_surface_load_to_pixbuf (GraniteDrawingBufferSurface* self);
VALA_EXTERN GType granite_drawing_color_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteDrawingColor, g_object_unref)
VALA_EXTERN GraniteDrawingColor* granite_drawing_buffer_surface_average_color (GraniteDrawingBufferSurface* self);
VALA_EXTERN void granite_drawing_buffer_surface_fast_blur (GraniteDrawingBufferSurface* self,
                                               gint radius,
                                               gint process_count);
VALA_EXTERN void granite_drawing_buffer_surface_exponential_blur (GraniteDrawingBufferSurface* self,
                                                      gint radius);
VALA_EXTERN void granite_drawing_buffer_surface_gaussian_blur (GraniteDrawingBufferSurface* self,
                                                   gint radius);
VALA_EXTERN GType granite_services_settings_serializable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesSettingsSerializable, g_object_unref)
VALA_EXTERN guint8 granite_drawing_color_alpha_from_int (gint color);
VALA_EXTERN guint8 granite_drawing_color_red_from_int (gint color);
VALA_EXTERN guint8 granite_drawing_color_green_from_int (gint color);
VALA_EXTERN guint8 granite_drawing_color_blue_from_int (gint color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_new (gdouble R,
                                                gdouble G,
                                                gdouble B,
                                                gdouble A);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_construct (GType object_type,
                                                      gdouble R,
                                                      gdouble G,
                                                      gdouble B,
                                                      gdouble A);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_new_from_gdk (GdkColor* color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_construct_from_gdk (GType object_type,
                                                               GdkColor* color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_new_from_rgba (GdkRGBA* color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_construct_from_rgba (GType object_type,
                                                                GdkRGBA* color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_new_from_string (const gchar* color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_construct_from_string (GType object_type,
                                                                  const gchar* color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_new_from_int (gint color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_construct_from_int (GType object_type,
                                                               gint color);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_hue (GraniteDrawingColor* self,
                                                    gdouble hue);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_sat (GraniteDrawingColor* self,
                                                    gdouble sat);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_val (GraniteDrawingColor* self,
                                                    gdouble val);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_alpha (GraniteDrawingColor* self,
                                                      gdouble alpha);
VALA_EXTERN gdouble granite_drawing_color_get_hue (GraniteDrawingColor* self);
VALA_EXTERN gdouble granite_drawing_color_get_sat (GraniteDrawingColor* self);
VALA_EXTERN gdouble granite_drawing_color_get_val (GraniteDrawingColor* self);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_add_hue (GraniteDrawingColor* self,
                                                    gdouble val);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_min_sat (GraniteDrawingColor* self,
                                                        gdouble sat);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_min_value (GraniteDrawingColor* self,
                                                          gdouble val);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_max_sat (GraniteDrawingColor* self,
                                                        gdouble sat);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_set_max_val (GraniteDrawingColor* self,
                                                        gdouble val);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_multiply_sat (GraniteDrawingColor* self,
                                                         gdouble amount);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_brighten_val (GraniteDrawingColor* self,
                                                         gdouble amount);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_darken_val (GraniteDrawingColor* self,
                                                       gdouble amount);
VALA_EXTERN GraniteDrawingColor* granite_drawing_color_darken_by_sat (GraniteDrawingColor* self,
                                                          gdouble amount);
VALA_EXTERN gchar* granite_drawing_color_to_string (GraniteDrawingColor* self);
VALA_EXTERN gint granite_drawing_color_to_int (GraniteDrawingColor* self);
VALA_EXTERN GType granite_drawing_utilities_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteDrawingUtilities, g_object_unref)
VALA_EXTERN void granite_drawing_utilities_cairo_rounded_rectangle (cairo_t* cr,
                                                        gdouble x,
                                                        gdouble y,
                                                        gdouble width,
                                                        gdouble height,
                                                        gdouble radius);
VALA_EXTERN GraniteDrawingColor* granite_drawing_utilities_average_color (GdkPixbuf* source);
VALA_EXTERN GraniteDrawingUtilities* granite_drawing_utilities_new (void);
VALA_EXTERN GraniteDrawingUtilities* granite_drawing_utilities_construct (GType object_type);
VALA_EXTERN void granite_services_application_set_badge (gint64 count,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_badge_finish (GAsyncResult* _res_,
                                                        GError** error);
VALA_EXTERN void granite_services_application_set_badge_visible (gboolean visible,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_badge_visible_finish (GAsyncResult* _res_,
                                                                GError** error);
VALA_EXTERN void granite_services_application_set_progress (gdouble progress,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_progress_finish (GAsyncResult* _res_,
                                                           GError** error);
VALA_EXTERN void granite_services_application_set_progress_visible (gboolean visible,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN gboolean granite_services_application_set_progress_visible_finish (GAsyncResult* _res_,
                                                                   GError** error);
VALA_EXTERN GType granite_services_contract_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesContract, g_object_unref)
VALA_EXTERN gchar* granite_services_contract_get_display_name (GraniteServicesContract* self);
VALA_EXTERN gchar* granite_services_contract_get_description (GraniteServicesContract* self);
VALA_EXTERN GIcon* granite_services_contract_get_icon (GraniteServicesContract* self);
VALA_EXTERN void granite_services_contract_execute_with_file (GraniteServicesContract* self,
                                                  GFile* file,
                                                  GError** error);
VALA_EXTERN void granite_services_contract_execute_with_files (GraniteServicesContract* self,
                                                   GFile** files,
                                                   gint files_length1,
                                                   GError** error);
VALA_EXTERN GQuark granite_services_contractor_error_quark (void);
VALA_EXTERN GType granite_services_contractor_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType granite_services_contractor_proxy_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesContractorProxy, g_object_unref)
VALA_EXTERN GraniteServicesContractorProxy* granite_services_contractor_proxy_get_instance (GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_all_contracts (GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_by_mime (const gchar* mime_type,
                                                                  GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_by_mimelist (gchar** mime_types,
                                                                      gint mime_types_length1,
                                                                      GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_for_file (GFile* file,
                                                                   GError** error);
VALA_EXTERN GeeList* granite_services_contractor_proxy_get_contracts_for_files (GFile** files,
                                                                    gint files_length1,
                                                                    GError** error);
VALA_EXTERN GType granite_services_icon_factory_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesIconFactory, g_object_unref)
VALA_EXTERN GraniteServicesIconFactory* granite_services_icon_factory;
VALA_EXTERN GraniteServicesIconFactory* granite_services_icon_factory_new (void);
VALA_EXTERN GraniteServicesIconFactory* granite_services_icon_factory_construct (GType object_type);
VALA_EXTERN GraniteServicesIconFactory* granite_services_icon_factory_get_default (void);
VALA_EXTERN GdkPixbuf* granite_services_icon_factory_load_symbolic_icon_from_gicon (GraniteServicesIconFactory* self,
                                                                        GtkStyleContext* style,
                                                                        GIcon* gicon,
                                                                        gint size) G_GNUC_DEPRECATED ;
VALA_EXTERN GdkPixbuf* granite_services_icon_factory_load_symbolic_icon (GraniteServicesIconFactory* self,
                                                             GtkStyleContext* style,
                                                             const gchar* iconname,
                                                             gint size) G_GNUC_DEPRECATED ;
VALA_EXTERN GType granite_services_log_level_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType granite_services_logger_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesLogger, g_object_unref)
VALA_EXTERN GraniteServicesLogLevel granite_services_logger_get_DisplayLevel (void);
VALA_EXTERN void granite_services_logger_set_DisplayLevel (GraniteServicesLogLevel value);
VALA_EXTERN void granite_services_logger_initialize (const gchar* app_name);
VALA_EXTERN void granite_services_logger_notification (const gchar* msg);
VALA_EXTERN GraniteServicesLogger* granite_services_logger_new (void);
VALA_EXTERN GraniteServicesLogger* granite_services_logger_construct (GType object_type);
VALA_EXTERN GType granite_services_paths_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesPaths, g_object_unref)
VALA_EXTERN GFile* granite_services_paths_get_home_folder (void);
VALA_EXTERN void granite_services_paths_set_home_folder (GFile* value);
VALA_EXTERN GFile* granite_services_paths_get_data_folder (void);
VALA_EXTERN void granite_services_paths_set_data_folder (GFile* value);
VALA_EXTERN GFile* granite_services_paths_get_xdg_config_home_folder (void);
VALA_EXTERN void granite_services_paths_set_xdg_config_home_folder (GFile* value);
VALA_EXTERN GFile* granite_services_paths_get_xdg_data_home_folder (void);
VALA_EXTERN void granite_services_paths_set_xdg_data_home_folder (GFile* value);
VALA_EXTERN GFile* granite_services_paths_get_xdg_cache_home_folder (void);
VALA_EXTERN void granite_services_paths_set_xdg_cache_home_folder (GFile* value);
VALA_EXTERN GList* granite_services_paths_get_xdg_data_dir_folders (void);
VALA_EXTERN void granite_services_paths_set_xdg_data_dir_folders (GList* value);
VALA_EXTERN GFile* granite_services_paths_get_user_config_folder (void);
VALA_EXTERN void granite_services_paths_set_user_config_folder (GFile* value);
VALA_EXTERN GFile* granite_services_paths_get_user_data_folder (void);
VALA_EXTERN void granite_services_paths_set_user_data_folder (GFile* value);
VALA_EXTERN GFile* granite_services_paths_get_user_cache_folder (void);
VALA_EXTERN void granite_services_paths_set_user_cache_folder (GFile* value);
VALA_EXTERN void granite_services_paths_initialize (const gchar* app_name,
                                        const gchar* data_folder_path);
VALA_EXTERN gboolean granite_services_paths_ensure_directory_exists (GFile* dir);
VALA_EXTERN GraniteServicesPaths* granite_services_paths_new (void);
VALA_EXTERN GraniteServicesPaths* granite_services_paths_construct (GType object_type);
VALA_EXTERN gchar* granite_services_settings_serializable_settings_serialize (GraniteServicesSettingsSerializable* self);
VALA_EXTERN void granite_services_settings_serializable_settings_deserialize (GraniteServicesSettingsSerializable* self,
                                                                  const gchar* s);
VALA_EXTERN GType granite_services_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesSettings, g_object_unref)
VALA_EXTERN GSettings* granite_services_settings_get_schema (GraniteServicesSettings* self);
VALA_EXTERN GraniteServicesSettings* granite_services_settings_construct (GType object_type,
                                                              const gchar* schema);
VALA_EXTERN GraniteServicesSettings* granite_services_settings_construct_with_backend (GType object_type,
                                                                           const gchar* schema,
                                                                           GSettingsBackend* backend);
VALA_EXTERN GraniteServicesSettings* granite_services_settings_construct_with_backend_and_path (GType object_type,
                                                                                    const gchar* schema,
                                                                                    GSettingsBackend* backend,
                                                                                    const gchar* path);
VALA_EXTERN GraniteServicesSettings* granite_services_settings_construct_with_path (GType object_type,
                                                                        const gchar* schema,
                                                                        const gchar* path);
VALA_EXTERN void granite_services_settings_verify (GraniteServicesSettings* self,
                                       const gchar* key);
VALA_EXTERN GType granite_services_simple_command_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesSimpleCommand, g_object_unref)
VALA_EXTERN GraniteServicesSimpleCommand* granite_services_simple_command_new (const gchar* dir,
                                                                   const gchar* command);
VALA_EXTERN GraniteServicesSimpleCommand* granite_services_simple_command_construct (GType object_type,
                                                                         const gchar* dir,
                                                                         const gchar* command);
VALA_EXTERN void granite_services_simple_command_run (GraniteServicesSimpleCommand* self);
VALA_EXTERN GType granite_services_system_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteServicesSystem, g_object_unref)
VALA_EXTERN void granite_services_system_open_uri (const gchar* uri) G_GNUC_DEPRECATED ;
VALA_EXTERN void granite_services_system_open (GFile* file) G_GNUC_DEPRECATED ;
VALA_EXTERN void granite_services_system_open_files (GFile** files,
                                         gint files_length1) G_GNUC_DEPRECATED ;
VALA_EXTERN void granite_services_system_launch (GFile* app) G_GNUC_DEPRECATED ;
VALA_EXTERN gboolean granite_services_system_execute_command (const gchar* command) G_GNUC_DEPRECATED ;
VALA_EXTERN void granite_services_system_launch_with_files (GFile* app,
                                                GFile** files,
                                                gint files_length1) G_GNUC_DEPRECATED ;
VALA_EXTERN gboolean granite_services_system_history_is_enabled (void);
VALA_EXTERN GraniteServicesSystem* granite_services_system_new (void);
VALA_EXTERN GraniteServicesSystem* granite_services_system_construct (GType object_type);
VALA_EXTERN GType granite_settings_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSettingsPage, g_object_unref)
VALA_EXTERN GType granite_settings_page_status_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraniteSettingsPageStatusType granite_settings_page_get_status_type (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_status_type (GraniteSettingsPage* self,
                                            GraniteSettingsPageStatusType value);
VALA_EXTERN GtkWidget* granite_settings_page_get_display_widget (GraniteSettingsPage* self);
VALA_EXTERN const gchar* granite_settings_page_get_header (GraniteSettingsPage* self);
VALA_EXTERN const gchar* granite_settings_page_get_status (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_status (GraniteSettingsPage* self,
                                       const gchar* value);
VALA_EXTERN const gchar* granite_settings_page_get_icon_name (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_icon_name (GraniteSettingsPage* self,
                                          const gchar* value);
VALA_EXTERN const gchar* granite_settings_page_get_title (GraniteSettingsPage* self);
VALA_EXTERN void granite_settings_page_set_title (GraniteSettingsPage* self,
                                      const gchar* value);
VALA_EXTERN GraniteSettingsPage* granite_settings_page_construct (GType object_type);
VALA_EXTERN GType granite_simple_settings_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSimpleSettingsPage, g_object_unref)
VALA_EXTERN GtkButtonBox* granite_simple_settings_page_get_action_area (GraniteSimpleSettingsPage* self);
VALA_EXTERN GtkGrid* granite_simple_settings_page_get_content_area (GraniteSimpleSettingsPage* self);
VALA_EXTERN GtkSwitch* granite_simple_settings_page_get_status_switch (GraniteSimpleSettingsPage* self);
VALA_EXTERN gboolean granite_simple_settings_page_get_activatable (GraniteSimpleSettingsPage* self);
VALA_EXTERN const gchar* granite_simple_settings_page_get_description (GraniteSimpleSettingsPage* self);
VALA_EXTERN void granite_simple_settings_page_set_description (GraniteSimpleSettingsPage* self,
                                                   const gchar* value);
VALA_EXTERN const gchar* granite_simple_settings_page_get_icon_name (GraniteSimpleSettingsPage* self);
VALA_EXTERN void granite_simple_settings_page_set_icon_name (GraniteSimpleSettingsPage* self,
                                                 const gchar* value);
VALA_EXTERN const gchar* granite_simple_settings_page_get_title (GraniteSimpleSettingsPage* self);
VALA_EXTERN void granite_simple_settings_page_set_title (GraniteSimpleSettingsPage* self,
                                             const gchar* value);
VALA_EXTERN GraniteSimpleSettingsPage* granite_simple_settings_page_construct (GType object_type);
VALA_EXTERN GType granite_accel_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteAccelLabel, g_object_unref)
VALA_EXTERN const gchar* granite_accel_label_get_action_name (GraniteAccelLabel* self);
VALA_EXTERN void granite_accel_label_set_action_name (GraniteAccelLabel* self,
                                          const gchar* value);
VALA_EXTERN const gchar* granite_accel_label_get_accel_string (GraniteAccelLabel* self);
VALA_EXTERN void granite_accel_label_set_accel_string (GraniteAccelLabel* self,
                                           const gchar* value);
VALA_EXTERN const gchar* granite_accel_label_get_label (GraniteAccelLabel* self);
VALA_EXTERN void granite_accel_label_set_label (GraniteAccelLabel* self,
                                    const gchar* value);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_new (const gchar* label,
                                            const gchar* accel_string);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_construct (GType object_type,
                                                  const gchar* label,
                                                  const gchar* accel_string);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_new_from_action_name (const gchar* label,
                                                             const gchar* action_name);
VALA_EXTERN GraniteAccelLabel* granite_accel_label_construct_from_action_name (GType object_type,
                                                                   const gchar* label,
                                                                   const gchar* action_name);
VALA_EXTERN GType granite_widgets_alert_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsAlertView, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_alert_view_get_title (GraniteWidgetsAlertView* self);
VALA_EXTERN void granite_widgets_alert_view_set_title (GraniteWidgetsAlertView* self,
                                           const gchar* value);
VALA_EXTERN const gchar* granite_widgets_alert_view_get_description (GraniteWidgetsAlertView* self);
VALA_EXTERN void granite_widgets_alert_view_set_description (GraniteWidgetsAlertView* self,
                                                 const gchar* value);
VALA_EXTERN gchar* granite_widgets_alert_view_get_icon_name (GraniteWidgetsAlertView* self);
VALA_EXTERN void granite_widgets_alert_view_set_icon_name (GraniteWidgetsAlertView* self,
                                               const gchar* value);
VALA_EXTERN GraniteWidgetsAlertView* granite_widgets_alert_view_new (const gchar* title,
                                                         const gchar* description,
                                                         const gchar* icon_name);
VALA_EXTERN GraniteWidgetsAlertView* granite_widgets_alert_view_construct (GType object_type,
                                                               const gchar* title,
                                                               const gchar* description,
                                                               const gchar* icon_name);
VALA_EXTERN void granite_widgets_alert_view_show_action (GraniteWidgetsAlertView* self,
                                             const gchar* label);
VALA_EXTERN void granite_widgets_alert_view_hide_action (GraniteWidgetsAlertView* self);
VALA_EXTERN GType granite_async_image_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteAsyncImage, g_object_unref)
VALA_EXTERN GIcon* granite_async_image_get_gicon_async (GraniteAsyncImage* self);
VALA_EXTERN gint granite_async_image_get_size_async (GraniteAsyncImage* self);
VALA_EXTERN GraniteAsyncImage* granite_async_image_new (gboolean load_on_realize,
                                            gboolean auto_size_request);
VALA_EXTERN GraniteAsyncImage* granite_async_image_construct (GType object_type,
                                                  gboolean load_on_realize,
                                                  gboolean auto_size_request);
VALA_EXTERN GraniteAsyncImage* granite_async_image_new_from_gicon_async (GIcon* icon,
                                                             gint size,
                                                             gboolean load_on_realize,
                                                             gboolean auto_size_request);
VALA_EXTERN GraniteAsyncImage* granite_async_image_construct_from_gicon_async (GType object_type,
                                                                   GIcon* icon,
                                                                   gint size,
                                                                   gboolean load_on_realize,
                                                                   gboolean auto_size_request);
VALA_EXTERN GraniteAsyncImage* granite_async_image_new_from_icon_name_async (const gchar* icon_name,
                                                                 GtkIconSize icon_size,
                                                                 gboolean load_on_realize,
                                                                 gboolean auto_size_request);
VALA_EXTERN GraniteAsyncImage* granite_async_image_construct_from_icon_name_async (GType object_type,
                                                                       const gchar* icon_name,
                                                                       GtkIconSize icon_size,
                                                                       gboolean load_on_realize,
                                                                       gboolean auto_size_request);
VALA_EXTERN void granite_async_image_set_from_gicon_async (GraniteAsyncImage* self,
                                               GIcon* icon,
                                               gint size,
                                               GCancellable* cancellable,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
VALA_EXTERN void granite_async_image_set_from_gicon_finish (GraniteAsyncImage* self,
                                                GAsyncResult* _res_,
                                                GError** error);
VALA_EXTERN void granite_async_image_set_from_icon_name_async (GraniteAsyncImage* self,
                                                   const gchar* icon_name,
                                                   GtkIconSize icon_size,
                                                   GCancellable* cancellable,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
VALA_EXTERN void granite_async_image_set_from_icon_name_finish (GraniteAsyncImage* self,
                                                    GAsyncResult* _res_,
                                                    GError** error);
VALA_EXTERN void granite_async_image_set_from_file_async (GraniteAsyncImage* self,
                                              GFile* file,
                                              gint width,
                                              gint height,
                                              gboolean preserve_aspect_ratio,
                                              GCancellable* cancellable,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
VALA_EXTERN void granite_async_image_set_from_file_finish (GraniteAsyncImage* self,
                                               GAsyncResult* _res_,
                                               GError** error);
VALA_EXTERN GType granite_widgets_avatar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsAvatar, g_object_unref)
VALA_EXTERN GdkPixbuf* granite_widgets_avatar_get_pixbuf (GraniteWidgetsAvatar* self);
VALA_EXTERN void granite_widgets_avatar_set_pixbuf (GraniteWidgetsAvatar* self,
                                        GdkPixbuf* value);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_new (void);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_construct (GType object_type);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_new_from_pixbuf (GdkPixbuf* pixbuf);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_construct_from_pixbuf (GType object_type,
                                                                    GdkPixbuf* pixbuf);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_new_from_file (const gchar* filepath,
                                                            gint pixel_size);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_construct_from_file (GType object_type,
                                                                  const gchar* filepath,
                                                                  gint pixel_size);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_new_with_default_icon (gint pixel_size);
VALA_EXTERN GraniteWidgetsAvatar* granite_widgets_avatar_construct_with_default_icon (GType object_type,
                                                                          gint pixel_size);
VALA_EXTERN void granite_widgets_avatar_show_default (GraniteWidgetsAvatar* self,
                                          gint pixel_size);
VALA_EXTERN GType granite_widgets_cell_renderer_badge_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsCellRendererBadge, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_cell_renderer_badge_get_text (GraniteWidgetsCellRendererBadge* self);
VALA_EXTERN void granite_widgets_cell_renderer_badge_set_text (GraniteWidgetsCellRendererBadge* self,
                                                   const gchar* value);
VALA_EXTERN GraniteWidgetsCellRendererBadge* granite_widgets_cell_renderer_badge_new (void);
VALA_EXTERN GraniteWidgetsCellRendererBadge* granite_widgets_cell_renderer_badge_construct (GType object_type);
VALA_EXTERN GType granite_widgets_cell_renderer_expander_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsCellRendererExpander, g_object_unref)
VALA_EXTERN gboolean granite_widgets_cell_renderer_expander_get_is_category_expander (GraniteWidgetsCellRendererExpander* self);
VALA_EXTERN void granite_widgets_cell_renderer_expander_set_is_category_expander (GraniteWidgetsCellRendererExpander* self,
                                                                      gboolean value);
VALA_EXTERN GraniteWidgetsCellRendererExpander* granite_widgets_cell_renderer_expander_new (void);
VALA_EXTERN GraniteWidgetsCellRendererExpander* granite_widgets_cell_renderer_expander_construct (GType object_type);
VALA_EXTERN gint granite_widgets_cell_renderer_expander_get_arrow_size (GraniteWidgetsCellRendererExpander* self,
                                                            GtkWidget* widget);
VALA_EXTERN GType granite_collapse_mode_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType granite_widgets_collapsible_paned_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsCollapsiblePaned, g_object_unref)
VALA_EXTERN GraniteCollapseMode granite_widgets_collapsible_paned_get_collapse_mode (GraniteWidgetsCollapsiblePaned* self);
VALA_EXTERN void granite_widgets_collapsible_paned_set_collapse_mode (GraniteWidgetsCollapsiblePaned* self,
                                                          GraniteCollapseMode value);
VALA_EXTERN GraniteWidgetsCollapsiblePaned* granite_widgets_collapsible_paned_new (GtkOrientation orientation);
VALA_EXTERN GraniteWidgetsCollapsiblePaned* granite_widgets_collapsible_paned_construct (GType object_type,
                                                                             GtkOrientation orientation);
VALA_EXTERN GType granite_widgets_composited_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsCompositedWindow, g_object_unref)
VALA_EXTERN GraniteWidgetsCompositedWindow* granite_widgets_composited_window_new (void);
VALA_EXTERN GraniteWidgetsCompositedWindow* granite_widgets_composited_window_construct (GType object_type);
VALA_EXTERN GType granite_widgets_date_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsDatePicker, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_date_picker_get_format (GraniteWidgetsDatePicker* self);
VALA_EXTERN GDateTime* granite_widgets_date_picker_get_date (GraniteWidgetsDatePicker* self);
VALA_EXTERN void granite_widgets_date_picker_set_date (GraniteWidgetsDatePicker* self,
                                           GDateTime* value);
VALA_EXTERN GraniteWidgetsDatePicker* granite_widgets_date_picker_new_with_format (const gchar* format);
VALA_EXTERN GraniteWidgetsDatePicker* granite_widgets_date_picker_construct_with_format (GType object_type,
                                                                             const gchar* format);
VALA_EXTERN void granite_widgets_date_picker_position_dropdown (GraniteWidgetsDatePicker* self,
                                                    GdkRectangle* rect);
VALA_EXTERN GraniteWidgetsDatePicker* granite_widgets_date_picker_new (void);
VALA_EXTERN GraniteWidgetsDatePicker* granite_widgets_date_picker_construct (GType object_type);
VALA_EXTERN GType granite_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteDialog, g_object_unref)
VALA_EXTERN GraniteDialog* granite_dialog_new (void);
VALA_EXTERN GraniteDialog* granite_dialog_construct (GType object_type);
VALA_EXTERN GType granite_widgets_tab_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsTab, g_object_unref)
 G_GNUC_INTERNAL GType granite_widgets_tab_page_container_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsTabPageContainer, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_tab_get_label (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_label (GraniteWidgetsTab* self,
                                    const gchar* value);
VALA_EXTERN void granite_widgets_tab_set_tooltip (GraniteWidgetsTab* self,
                                      const gchar* value);
VALA_EXTERN gboolean granite_widgets_tab_get_pinned (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_pinned (GraniteWidgetsTab* self,
                                     gboolean value);
VALA_EXTERN gboolean granite_widgets_tab_get_pinnable (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_pinnable (GraniteWidgetsTab* self,
                                       gboolean value);
VALA_EXTERN const gchar* granite_widgets_tab_get_restore_data (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_restore_data (GraniteWidgetsTab* self,
                                           const gchar* value);
VALA_EXTERN GraniteAccelLabel* granite_widgets_tab_get_close_tab_label (GraniteWidgetsTab* self);
VALA_EXTERN GraniteAccelLabel* granite_widgets_tab_get_duplicate_tab_label (GraniteWidgetsTab* self);
VALA_EXTERN GraniteAccelLabel* granite_widgets_tab_get_new_window_label (GraniteWidgetsTab* self);
VALA_EXTERN GtkWidget* granite_widgets_tab_get_page (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_page (GraniteWidgetsTab* self,
                                   GtkWidget* value);
VALA_EXTERN GIcon* granite_widgets_tab_get_icon (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_icon (GraniteWidgetsTab* self,
                                   GIcon* value);
VALA_EXTERN gboolean granite_widgets_tab_get_working (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_working (GraniteWidgetsTab* self,
                                      gboolean value);
VALA_EXTERN PangoEllipsizeMode granite_widgets_tab_get_ellipsize_mode (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_ellipsize_mode (GraniteWidgetsTab* self,
                                             PangoEllipsizeMode value);
VALA_EXTERN GtkMenu* granite_widgets_tab_get_menu (GraniteWidgetsTab* self);
VALA_EXTERN void granite_widgets_tab_set_menu (GraniteWidgetsTab* self,
                                   GtkMenu* value);
VALA_EXTERN GraniteWidgetsTab* granite_widgets_tab_new (const gchar* label,
                                            GIcon* icon,
                                            GtkWidget* page);
VALA_EXTERN GraniteWidgetsTab* granite_widgets_tab_construct (GType object_type,
                                                  const gchar* label,
                                                  GIcon* icon,
                                                  GtkWidget* page);
VALA_EXTERN GraniteWidgetsTab* granite_widgets_tab_new_with_accellabels (const gchar* label,
                                                             GIcon* icon,
                                                             GtkWidget* page,
                                                             GraniteAccelLabel* _close_tab_label,
                                                             GraniteAccelLabel* _duplicate_tab_label,
                                                             GraniteAccelLabel* _new_window_label);
VALA_EXTERN GraniteWidgetsTab* granite_widgets_tab_construct_with_accellabels (GType object_type,
                                                                   const gchar* label,
                                                                   GIcon* icon,
                                                                   GtkWidget* page,
                                                                   GraniteAccelLabel* _close_tab_label,
                                                                   GraniteAccelLabel* _duplicate_tab_label,
                                                                   GraniteAccelLabel* _new_window_label);
VALA_EXTERN void granite_widgets_tab_close (GraniteWidgetsTab* self);
VALA_EXTERN GType granite_widgets_dynamic_notebook_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsDynamicNotebook, g_object_unref)
VALA_EXTERN GType granite_widgets_dynamic_notebook_tab_bar_behavior_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gint granite_widgets_dynamic_notebook_get_n_tabs (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_show_tabs (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_show_tabs (GraniteWidgetsDynamicNotebook* self,
                                                     gboolean value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_tabs_closable (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_tabs_closable (GraniteWidgetsDynamicNotebook* self,
                                                         gboolean value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_allow_drag (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_allow_drag (GraniteWidgetsDynamicNotebook* self,
                                                      gboolean value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_allow_new_window (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_allow_new_window (GraniteWidgetsDynamicNotebook* self,
                                                            gboolean value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_allow_duplication (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_allow_duplication (GraniteWidgetsDynamicNotebook* self,
                                                             gboolean value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_allow_restoring (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_allow_restoring (GraniteWidgetsDynamicNotebook* self,
                                                           gboolean value);
VALA_EXTERN gint granite_widgets_dynamic_notebook_get_max_restorable_tabs (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_max_restorable_tabs (GraniteWidgetsDynamicNotebook* self,
                                                               gint value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_add_button_visible (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_add_button_visible (GraniteWidgetsDynamicNotebook* self,
                                                              gboolean value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_allow_pinning (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_allow_pinning (GraniteWidgetsDynamicNotebook* self,
                                                         gboolean value);
VALA_EXTERN gboolean granite_widgets_dynamic_notebook_get_force_left (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_force_left (GraniteWidgetsDynamicNotebook* self,
                                                      gboolean value);
VALA_EXTERN const gchar* granite_widgets_dynamic_notebook_get_add_button_tooltip (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_add_button_tooltip (GraniteWidgetsDynamicNotebook* self,
                                                              const gchar* value);
VALA_EXTERN GraniteAccelLabel* granite_widgets_dynamic_notebook_get_new_tab_label (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN GraniteAccelLabel* granite_widgets_dynamic_notebook_get_restore_tab_label (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN GraniteWidgetsTab* granite_widgets_dynamic_notebook_get_current (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_current (GraniteWidgetsDynamicNotebook* self,
                                                   GraniteWidgetsTab* value);
VALA_EXTERN GList* granite_widgets_dynamic_notebook_get_tabs (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN const gchar* granite_widgets_dynamic_notebook_get_group_name (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_group_name (GraniteWidgetsDynamicNotebook* self,
                                                      const gchar* value);
VALA_EXTERN GraniteWidgetsDynamicNotebookTabBarBehavior granite_widgets_dynamic_notebook_get_tab_bar_behavior (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_tab_bar_behavior (GraniteWidgetsDynamicNotebook* self,
                                                            GraniteWidgetsDynamicNotebookTabBarBehavior value);
VALA_EXTERN GtkMenu* granite_widgets_dynamic_notebook_get_menu (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN GraniteWidgetsDynamicNotebook* granite_widgets_dynamic_notebook_new (void);
VALA_EXTERN GraniteWidgetsDynamicNotebook* granite_widgets_dynamic_notebook_construct (GType object_type);
VALA_EXTERN GraniteWidgetsDynamicNotebook* granite_widgets_dynamic_notebook_new_with_accellabels (GraniteAccelLabel* new_tab_label,
                                                                                      GraniteAccelLabel* restore_tab_label);
VALA_EXTERN GraniteWidgetsDynamicNotebook* granite_widgets_dynamic_notebook_construct_with_accellabels (GType object_type,
                                                                                            GraniteAccelLabel* new_tab_label,
                                                                                            GraniteAccelLabel* restore_tab_label);
VALA_EXTERN void granite_widgets_dynamic_notebook_remove_tab (GraniteWidgetsDynamicNotebook* self,
                                                  GraniteWidgetsTab* tab);
VALA_EXTERN void granite_widgets_dynamic_notebook_next_page (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN void granite_widgets_dynamic_notebook_previous_page (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN GList* granite_widgets_dynamic_notebook_get_children (GraniteWidgetsDynamicNotebook* self);
VALA_EXTERN gint granite_widgets_dynamic_notebook_get_tab_position (GraniteWidgetsDynamicNotebook* self,
                                                        GraniteWidgetsTab* tab);
VALA_EXTERN void granite_widgets_dynamic_notebook_set_tab_position (GraniteWidgetsDynamicNotebook* self,
                                                        GraniteWidgetsTab* tab,
                                                        gint position);
VALA_EXTERN GraniteWidgetsTab* granite_widgets_dynamic_notebook_get_tab_by_index (GraniteWidgetsDynamicNotebook* self,
                                                                      gint index);
VALA_EXTERN GraniteWidgetsTab* granite_widgets_dynamic_notebook_get_tab_by_widget (GraniteWidgetsDynamicNotebook* self,
                                                                       GtkWidget* widget);
VALA_EXTERN GtkWidget* granite_widgets_dynamic_notebook_get_nth_page (GraniteWidgetsDynamicNotebook* self,
                                                          gint index);
VALA_EXTERN guint granite_widgets_dynamic_notebook_insert_tab (GraniteWidgetsDynamicNotebook* self,
                                                   GraniteWidgetsTab* tab,
                                                   gint index);
VALA_EXTERN GType granite_header_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteHeaderLabel, g_object_unref)
VALA_EXTERN GraniteHeaderLabel* granite_header_label_new (const gchar* label);
VALA_EXTERN GraniteHeaderLabel* granite_header_label_construct (GType object_type,
                                                    const gchar* label);
VALA_EXTERN GType granite_hyper_text_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteHyperTextView, g_object_unref)
VALA_EXTERN GraniteHyperTextView* granite_hyper_text_view_new (void);
VALA_EXTERN GraniteHyperTextView* granite_hyper_text_view_construct (GType object_type);
VALA_EXTERN GType granite_message_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteMessageDialog, g_object_unref)
VALA_EXTERN const gchar* granite_message_dialog_get_primary_text (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_primary_text (GraniteMessageDialog* self,
                                              const gchar* value);
VALA_EXTERN const gchar* granite_message_dialog_get_secondary_text (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_secondary_text (GraniteMessageDialog* self,
                                                const gchar* value);
VALA_EXTERN GIcon* granite_message_dialog_get_image_icon (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_image_icon (GraniteMessageDialog* self,
                                            GIcon* value);
VALA_EXTERN GIcon* granite_message_dialog_get_badge_icon (GraniteMessageDialog* self);
VALA_EXTERN void granite_message_dialog_set_badge_icon (GraniteMessageDialog* self,
                                            GIcon* value);
VALA_EXTERN GtkLabel* granite_message_dialog_get_primary_label (GraniteMessageDialog* self);
VALA_EXTERN GtkLabel* granite_message_dialog_get_secondary_label (GraniteMessageDialog* self);
VALA_EXTERN GtkBin* granite_message_dialog_get_custom_bin (GraniteMessageDialog* self);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_new (const gchar* primary_text,
                                                  const gchar* secondary_text,
                                                  GIcon* image_icon,
                                                  GtkButtonsType buttons);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_construct (GType object_type,
                                                        const gchar* primary_text,
                                                        const gchar* secondary_text,
                                                        GIcon* image_icon,
                                                        GtkButtonsType buttons);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_new_with_image_from_icon_name (const gchar* primary_text,
                                                                            const gchar* secondary_text,
                                                                            const gchar* image_icon_name,
                                                                            GtkButtonsType buttons);
VALA_EXTERN GraniteMessageDialog* granite_message_dialog_construct_with_image_from_icon_name (GType object_type,
                                                                                  const gchar* primary_text,
                                                                                  const gchar* secondary_text,
                                                                                  const gchar* image_icon_name,
                                                                                  GtkButtonsType buttons);
VALA_EXTERN void granite_message_dialog_show_error_details (GraniteMessageDialog* self,
                                                const gchar* error_message);
VALA_EXTERN GType granite_widgets_mode_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsModeButton, g_object_unref)
VALA_EXTERN gint granite_widgets_mode_button_get_selected (GraniteWidgetsModeButton* self);
VALA_EXTERN void granite_widgets_mode_button_set_selected (GraniteWidgetsModeButton* self,
                                               gint value);
VALA_EXTERN guint granite_widgets_mode_button_get_n_items (GraniteWidgetsModeButton* self);
VALA_EXTERN GraniteWidgetsModeButton* granite_widgets_mode_button_new (void);
VALA_EXTERN GraniteWidgetsModeButton* granite_widgets_mode_button_construct (GType object_type);
VALA_EXTERN gint granite_widgets_mode_button_append_pixbuf (GraniteWidgetsModeButton* self,
                                                GdkPixbuf* pixbuf);
VALA_EXTERN gint granite_widgets_mode_button_append_text (GraniteWidgetsModeButton* self,
                                              const gchar* text);
VALA_EXTERN gint granite_widgets_mode_button_append_icon (GraniteWidgetsModeButton* self,
                                              const gchar* icon_name,
                                              GtkIconSize size);
VALA_EXTERN gint granite_widgets_mode_button_append (GraniteWidgetsModeButton* self,
                                         GtkWidget* w);
VALA_EXTERN void granite_widgets_mode_button_set_active (GraniteWidgetsModeButton* self,
                                             gint new_active_index);
VALA_EXTERN void granite_widgets_mode_button_set_item_visible (GraniteWidgetsModeButton* self,
                                                   gint index,
                                                   gboolean val);
VALA_EXTERN void granite_widgets_mode_button_remove (GraniteWidgetsModeButton* self,
                                         gint index);
VALA_EXTERN void granite_widgets_mode_button_clear_children (GraniteWidgetsModeButton* self);
VALA_EXTERN GType granite_mode_switch_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteModeSwitch, g_object_unref)
VALA_EXTERN gboolean granite_mode_switch_get_active (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_active (GraniteModeSwitch* self,
                                     gboolean value);
VALA_EXTERN GIcon* granite_mode_switch_get_primary_icon_gicon (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_primary_icon_gicon (GraniteModeSwitch* self,
                                                 GIcon* value);
VALA_EXTERN const gchar* granite_mode_switch_get_primary_icon_name (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_primary_icon_name (GraniteModeSwitch* self,
                                                const gchar* value);
VALA_EXTERN const gchar* granite_mode_switch_get_primary_icon_tooltip_text (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_primary_icon_tooltip_text (GraniteModeSwitch* self,
                                                        const gchar* value);
VALA_EXTERN GIcon* granite_mode_switch_get_secondary_icon_gicon (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_secondary_icon_gicon (GraniteModeSwitch* self,
                                                   GIcon* value);
VALA_EXTERN const gchar* granite_mode_switch_get_secondary_icon_name (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_secondary_icon_name (GraniteModeSwitch* self,
                                                  const gchar* value);
VALA_EXTERN const gchar* granite_mode_switch_get_secondary_icon_tooltip_text (GraniteModeSwitch* self);
VALA_EXTERN void granite_mode_switch_set_secondary_icon_tooltip_text (GraniteModeSwitch* self,
                                                          const gchar* value);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_new (GIcon* primary_icon_gicon,
                                            GIcon* secondary_icon_gicon);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_construct (GType object_type,
                                                  GIcon* primary_icon_gicon,
                                                  GIcon* secondary_icon_gicon);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_new_from_icon_name (const gchar* primary_icon_name,
                                                           const gchar* secondary_icon_name);
VALA_EXTERN GraniteModeSwitch* granite_mode_switch_construct_from_icon_name (GType object_type,
                                                                 const gchar* primary_icon_name,
                                                                 const gchar* secondary_icon_name);
VALA_EXTERN GType granite_widgets_overlay_bar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsOverlayBar, g_object_unref)
VALA_EXTERN GtkOverlay* granite_widgets_overlay_bar_get_overlay (GraniteWidgetsOverlayBar* self) G_GNUC_DEPRECATED ;
VALA_EXTERN const gchar* granite_widgets_overlay_bar_get_status (GraniteWidgetsOverlayBar* self) G_GNUC_DEPRECATED ;
VALA_EXTERN void granite_widgets_overlay_bar_set_status (GraniteWidgetsOverlayBar* self,
                                             const gchar* value) G_GNUC_DEPRECATED ;
VALA_EXTERN const gchar* granite_widgets_overlay_bar_get_label (GraniteWidgetsOverlayBar* self);
VALA_EXTERN void granite_widgets_overlay_bar_set_label (GraniteWidgetsOverlayBar* self,
                                            const gchar* value);
VALA_EXTERN gboolean granite_widgets_overlay_bar_get_active (GraniteWidgetsOverlayBar* self);
VALA_EXTERN void granite_widgets_overlay_bar_set_active (GraniteWidgetsOverlayBar* self,
                                             gboolean value);
VALA_EXTERN GraniteWidgetsOverlayBar* granite_widgets_overlay_bar_new (GtkOverlay* overlay);
VALA_EXTERN GraniteWidgetsOverlayBar* granite_widgets_overlay_bar_construct (GType object_type,
                                                                 GtkOverlay* overlay);
VALA_EXTERN GType granite_seek_bar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSeekBar, g_object_unref)
VALA_EXTERN gdouble granite_seek_bar_get_playback_duration (GraniteSeekBar* self);
VALA_EXTERN void granite_seek_bar_set_playback_duration (GraniteSeekBar* self,
                                             gdouble value);
VALA_EXTERN gdouble granite_seek_bar_get_playback_progress (GraniteSeekBar* self);
VALA_EXTERN void granite_seek_bar_set_playback_progress (GraniteSeekBar* self,
                                             gdouble value);
VALA_EXTERN gboolean granite_seek_bar_get_is_grabbing (GraniteSeekBar* self);
VALA_EXTERN gboolean granite_seek_bar_get_is_hovering (GraniteSeekBar* self);
VALA_EXTERN GtkLabel* granite_seek_bar_get_progression_label (GraniteSeekBar* self);
VALA_EXTERN void granite_seek_bar_set_progression_label (GraniteSeekBar* self,
                                             GtkLabel* value);
VALA_EXTERN GtkLabel* granite_seek_bar_get_duration_label (GraniteSeekBar* self);
VALA_EXTERN void granite_seek_bar_set_duration_label (GraniteSeekBar* self,
                                          GtkLabel* value);
VALA_EXTERN GtkScale* granite_seek_bar_get_scale (GraniteSeekBar* self);
VALA_EXTERN void granite_seek_bar_set_scale (GraniteSeekBar* self,
                                 GtkScale* value);
VALA_EXTERN GraniteSeekBar* granite_seek_bar_new (gdouble playback_duration);
VALA_EXTERN GraniteSeekBar* granite_seek_bar_construct (GType object_type,
                                            gdouble playback_duration);
VALA_EXTERN GType granite_settings_sidebar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSettingsSidebar, g_object_unref)
VALA_EXTERN GtkStack* granite_settings_sidebar_get_stack (GraniteSettingsSidebar* self);
VALA_EXTERN const gchar* granite_settings_sidebar_get_visible_child_name (GraniteSettingsSidebar* self);
VALA_EXTERN void granite_settings_sidebar_set_visible_child_name (GraniteSettingsSidebar* self,
                                                      const gchar* value);
VALA_EXTERN GraniteSettingsSidebar* granite_settings_sidebar_new (GtkStack* stack);
VALA_EXTERN GraniteSettingsSidebar* granite_settings_sidebar_construct (GType object_type,
                                                            GtkStack* stack);
VALA_EXTERN GType granite_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSettings, g_object_unref)
VALA_EXTERN GType granite_settings_color_scheme_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GraniteSettingsColorScheme granite_settings_get_prefers_color_scheme (GraniteSettings* self);
VALA_EXTERN GraniteSettings* granite_settings_get_default (void);
VALA_EXTERN GType granite_widgets_source_list_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsSourceListItem, g_object_unref)
VALA_EXTERN GType granite_widgets_source_list_expandable_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsSourceListExpandableItem, g_object_unref)
VALA_EXTERN GType granite_widgets_source_list_sortable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsSourceListSortable, g_object_unref)
VALA_EXTERN gboolean granite_widgets_source_list_sortable_allow_dnd_sorting (GraniteWidgetsSourceListSortable* self);
VALA_EXTERN gint granite_widgets_source_list_sortable_compare (GraniteWidgetsSourceListSortable* self,
                                                   GraniteWidgetsSourceListItem* a,
                                                   GraniteWidgetsSourceListItem* b);
VALA_EXTERN GType granite_widgets_source_list_drag_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsSourceListDragSource, g_object_unref)
VALA_EXTERN gboolean granite_widgets_source_list_drag_source_draggable (GraniteWidgetsSourceListDragSource* self);
VALA_EXTERN void granite_widgets_source_list_drag_source_prepare_selection_data (GraniteWidgetsSourceListDragSource* self,
                                                                     GtkSelectionData* selection_data);
VALA_EXTERN GType granite_widgets_source_list_drag_dest_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsSourceListDragDest, g_object_unref)
VALA_EXTERN gboolean granite_widgets_source_list_drag_dest_data_drop_possible (GraniteWidgetsSourceListDragDest* self,
                                                                   GdkDragContext* context,
                                                                   GtkSelectionData* data);
VALA_EXTERN GdkDragAction granite_widgets_source_list_drag_dest_data_received (GraniteWidgetsSourceListDragDest* self,
                                                                   GdkDragContext* context,
                                                                   GtkSelectionData* data);
VALA_EXTERN GType granite_widgets_source_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsSourceList, g_object_unref)
VALA_EXTERN GraniteWidgetsSourceListExpandableItem* granite_widgets_source_list_get_root (GraniteWidgetsSourceList* self);
VALA_EXTERN void granite_widgets_source_list_set_root (GraniteWidgetsSourceList* self,
                                           GraniteWidgetsSourceListExpandableItem* value);
VALA_EXTERN GraniteWidgetsSourceListItem* granite_widgets_source_list_get_selected (GraniteWidgetsSourceList* self);
VALA_EXTERN void granite_widgets_source_list_set_selected (GraniteWidgetsSourceList* self,
                                               GraniteWidgetsSourceListItem* value);
VALA_EXTERN PangoEllipsizeMode granite_widgets_source_list_get_ellipsize_mode (GraniteWidgetsSourceList* self);
VALA_EXTERN void granite_widgets_source_list_set_ellipsize_mode (GraniteWidgetsSourceList* self,
                                                     PangoEllipsizeMode value);
VALA_EXTERN gboolean granite_widgets_source_list_get_editing (GraniteWidgetsSourceList* self);
VALA_EXTERN GraniteWidgetsSourceList* granite_widgets_source_list_new (GraniteWidgetsSourceListExpandableItem* root);
VALA_EXTERN GraniteWidgetsSourceList* granite_widgets_source_list_construct (GType object_type,
                                                                 GraniteWidgetsSourceListExpandableItem* root);
VALA_EXTERN gboolean granite_widgets_source_list_has_item (GraniteWidgetsSourceList* self,
                                               GraniteWidgetsSourceListItem* item);
VALA_EXTERN void granite_widgets_source_list_set_filter_func (GraniteWidgetsSourceList* self,
                                                  GraniteWidgetsSourceListVisibleFunc visible_func,
                                                  gpointer visible_func_target,
                                                  gboolean refilter);
VALA_EXTERN void granite_widgets_source_list_refilter (GraniteWidgetsSourceList* self);
VALA_EXTERN gboolean granite_widgets_source_list_is_item_expanded (GraniteWidgetsSourceList* self,
                                                       GraniteWidgetsSourceListItem* item);
VALA_EXTERN gboolean granite_widgets_source_list_start_editing_item (GraniteWidgetsSourceList* self,
                                                         GraniteWidgetsSourceListItem* item);
VALA_EXTERN void granite_widgets_source_list_stop_editing (GraniteWidgetsSourceList* self);
VALA_EXTERN void granite_widgets_source_list_enable_drag_source (GraniteWidgetsSourceList* self,
                                                     GtkTargetEntry* src_entries,
                                                     gint src_entries_length1);
VALA_EXTERN void granite_widgets_source_list_disable_drag_source (GraniteWidgetsSourceList* self);
VALA_EXTERN void granite_widgets_source_list_enable_drag_dest (GraniteWidgetsSourceList* self,
                                                   GtkTargetEntry* dest_entries,
                                                   gint dest_entries_length1,
                                                   GdkDragAction actions);
VALA_EXTERN void granite_widgets_source_list_disable_drag_dest (GraniteWidgetsSourceList* self);
VALA_EXTERN gboolean granite_widgets_source_list_scroll_to_item (GraniteWidgetsSourceList* self,
                                                     GraniteWidgetsSourceListItem* item,
                                                     gboolean expand_parents,
                                                     gboolean use_align,
                                                     gfloat row_align);
VALA_EXTERN GraniteWidgetsSourceListItem* granite_widgets_source_list_get_previous_item (GraniteWidgetsSourceList* self,
                                                                             GraniteWidgetsSourceListItem* reference);
VALA_EXTERN GraniteWidgetsSourceListItem* granite_widgets_source_list_get_next_item (GraniteWidgetsSourceList* self,
                                                                         GraniteWidgetsSourceListItem* reference);
VALA_EXTERN GraniteWidgetsSourceListItem* granite_widgets_source_list_get_first_child (GraniteWidgetsSourceList* self,
                                                                           GraniteWidgetsSourceListExpandableItem* parent);
VALA_EXTERN GraniteWidgetsSourceListItem* granite_widgets_source_list_get_last_child (GraniteWidgetsSourceList* self,
                                                                          GraniteWidgetsSourceListExpandableItem* parent);
VALA_EXTERN guint granite_widgets_source_list_get_n_visible_children (GraniteWidgetsSourceList* self,
                                                          GraniteWidgetsSourceListExpandableItem* parent);
VALA_EXTERN GraniteWidgetsSourceListExpandableItem* granite_widgets_source_list_item_get_parent (GraniteWidgetsSourceListItem* self);
VALA_EXTERN const gchar* granite_widgets_source_list_item_get_name (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_name (GraniteWidgetsSourceListItem* self,
                                                const gchar* value);
VALA_EXTERN const gchar* granite_widgets_source_list_item_get_tooltip (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_tooltip (GraniteWidgetsSourceListItem* self,
                                                   const gchar* value);
VALA_EXTERN const gchar* granite_widgets_source_list_item_get_markup (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_markup (GraniteWidgetsSourceListItem* self,
                                                  const gchar* value);
VALA_EXTERN const gchar* granite_widgets_source_list_item_get_badge (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_badge (GraniteWidgetsSourceListItem* self,
                                                 const gchar* value);
VALA_EXTERN gboolean granite_widgets_source_list_item_get_editable (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_editable (GraniteWidgetsSourceListItem* self,
                                                    gboolean value);
VALA_EXTERN gboolean granite_widgets_source_list_item_get_visible (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_visible (GraniteWidgetsSourceListItem* self,
                                                   gboolean value);
VALA_EXTERN gboolean granite_widgets_source_list_item_get_selectable (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_selectable (GraniteWidgetsSourceListItem* self,
                                                      gboolean value);
VALA_EXTERN GIcon* granite_widgets_source_list_item_get_icon (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_icon (GraniteWidgetsSourceListItem* self,
                                                GIcon* value);
VALA_EXTERN GIcon* granite_widgets_source_list_item_get_activatable (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_activatable (GraniteWidgetsSourceListItem* self,
                                                       GIcon* value);
VALA_EXTERN const gchar* granite_widgets_source_list_item_get_activatable_tooltip (GraniteWidgetsSourceListItem* self);
VALA_EXTERN void granite_widgets_source_list_item_set_activatable_tooltip (GraniteWidgetsSourceListItem* self,
                                                               const gchar* value);
VALA_EXTERN GraniteWidgetsSourceListItem* granite_widgets_source_list_item_new (const gchar* name);
VALA_EXTERN GraniteWidgetsSourceListItem* granite_widgets_source_list_item_construct (GType object_type,
                                                                          const gchar* name);
VALA_EXTERN GtkMenu* granite_widgets_source_list_item_get_context_menu (GraniteWidgetsSourceListItem* self);
VALA_EXTERN gboolean granite_widgets_source_list_expandable_item_get_collapsible (GraniteWidgetsSourceListExpandableItem* self);
VALA_EXTERN void granite_widgets_source_list_expandable_item_set_collapsible (GraniteWidgetsSourceListExpandableItem* self,
                                                                  gboolean value);
VALA_EXTERN gboolean granite_widgets_source_list_expandable_item_get_expanded (GraniteWidgetsSourceListExpandableItem* self);
VALA_EXTERN void granite_widgets_source_list_expandable_item_set_expanded (GraniteWidgetsSourceListExpandableItem* self,
                                                               gboolean value);
VALA_EXTERN guint granite_widgets_source_list_expandable_item_get_n_children (GraniteWidgetsSourceListExpandableItem* self);
VALA_EXTERN GeeCollection* granite_widgets_source_list_expandable_item_get_children (GraniteWidgetsSourceListExpandableItem* self);
VALA_EXTERN GraniteWidgetsSourceListExpandableItem* granite_widgets_source_list_expandable_item_new (const gchar* name);
VALA_EXTERN GraniteWidgetsSourceListExpandableItem* granite_widgets_source_list_expandable_item_construct (GType object_type,
                                                                                               const gchar* name);
VALA_EXTERN gboolean granite_widgets_source_list_expandable_item_contains (GraniteWidgetsSourceListExpandableItem* self,
                                                               GraniteWidgetsSourceListItem* item);
VALA_EXTERN void granite_widgets_source_list_expandable_item_add (GraniteWidgetsSourceListExpandableItem* self,
                                                      GraniteWidgetsSourceListItem* item);
VALA_EXTERN void granite_widgets_source_list_expandable_item_remove (GraniteWidgetsSourceListExpandableItem* self,
                                                         GraniteWidgetsSourceListItem* item);
VALA_EXTERN void granite_widgets_source_list_expandable_item_clear (GraniteWidgetsSourceListExpandableItem* self);
VALA_EXTERN void granite_widgets_source_list_expandable_item_expand_all (GraniteWidgetsSourceListExpandableItem* self,
                                                             gboolean inclusive,
                                                             gboolean recursive);
VALA_EXTERN void granite_widgets_source_list_expandable_item_collapse_all (GraniteWidgetsSourceListExpandableItem* self,
                                                               gboolean inclusive,
                                                               gboolean recursive);
VALA_EXTERN void granite_widgets_source_list_expandable_item_expand_with_parents (GraniteWidgetsSourceListExpandableItem* self);
VALA_EXTERN void granite_widgets_source_list_expandable_item_collapse_with_parents (GraniteWidgetsSourceListExpandableItem* self);
VALA_EXTERN GType granite_widgets_storage_bar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsStorageBar, g_object_unref)
VALA_EXTERN GType granite_widgets_storage_bar_item_description_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* granite_widgets_storage_bar_item_description_get_class (GraniteWidgetsStorageBarItemDescription description);
VALA_EXTERN gchar* granite_widgets_storage_bar_item_description_get_name (GraniteWidgetsStorageBarItemDescription description);
VALA_EXTERN guint64 granite_widgets_storage_bar_get_storage (GraniteWidgetsStorageBar* self);
VALA_EXTERN void granite_widgets_storage_bar_set_storage (GraniteWidgetsStorageBar* self,
                                              guint64 value);
VALA_EXTERN guint64 granite_widgets_storage_bar_get_total_usage (GraniteWidgetsStorageBar* self);
VALA_EXTERN void granite_widgets_storage_bar_set_total_usage (GraniteWidgetsStorageBar* self,
                                                  guint64 value);
VALA_EXTERN gint granite_widgets_storage_bar_get_inner_margin_sides (GraniteWidgetsStorageBar* self);
VALA_EXTERN void granite_widgets_storage_bar_set_inner_margin_sides (GraniteWidgetsStorageBar* self,
                                                         gint value);
VALA_EXTERN GraniteWidgetsStorageBar* granite_widgets_storage_bar_new (guint64 storage);
VALA_EXTERN GraniteWidgetsStorageBar* granite_widgets_storage_bar_construct (GType object_type,
                                                                 guint64 storage);
VALA_EXTERN GraniteWidgetsStorageBar* granite_widgets_storage_bar_new_with_total_usage (guint64 storage,
                                                                            guint64 total_usage);
VALA_EXTERN GraniteWidgetsStorageBar* granite_widgets_storage_bar_construct_with_total_usage (GType object_type,
                                                                                  guint64 storage,
                                                                                  guint64 total_usage);
VALA_EXTERN void granite_widgets_storage_bar_update_block_size (GraniteWidgetsStorageBar* self,
                                                    GraniteWidgetsStorageBarItemDescription description,
                                                    guint64 size);
VALA_EXTERN GType granite_switch_model_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteSwitchModelButton, g_object_unref)
VALA_EXTERN const gchar* granite_switch_model_button_get_text (GraniteSwitchModelButton* self);
VALA_EXTERN void granite_switch_model_button_set_text (GraniteSwitchModelButton* self,
                                           const gchar* value);
VALA_EXTERN const gchar* granite_switch_model_button_get_description (GraniteSwitchModelButton* self);
VALA_EXTERN void granite_switch_model_button_set_description (GraniteSwitchModelButton* self,
                                                  const gchar* value);
VALA_EXTERN GraniteSwitchModelButton* granite_switch_model_button_new (const gchar* text);
VALA_EXTERN GraniteSwitchModelButton* granite_switch_model_button_construct (GType object_type,
                                                                 const gchar* text);
VALA_EXTERN GType granite_widgets_time_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsTimePicker, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_time_picker_get_format_12 (GraniteWidgetsTimePicker* self);
VALA_EXTERN const gchar* granite_widgets_time_picker_get_format_24 (GraniteWidgetsTimePicker* self);
VALA_EXTERN GDateTime* granite_widgets_time_picker_get_time (GraniteWidgetsTimePicker* self);
VALA_EXTERN void granite_widgets_time_picker_set_time (GraniteWidgetsTimePicker* self,
                                           GDateTime* value);
VALA_EXTERN GraniteWidgetsTimePicker* granite_widgets_time_picker_new_with_format (const gchar* format_12,
                                                                       const gchar* format_24);
VALA_EXTERN GraniteWidgetsTimePicker* granite_widgets_time_picker_construct_with_format (GType object_type,
                                                                             const gchar* format_12,
                                                                             const gchar* format_24);
VALA_EXTERN void granite_widgets_time_picker_position_dropdown (GraniteWidgetsTimePicker* self,
                                                    gint* x,
                                                    gint* y) G_GNUC_DEPRECATED ;
VALA_EXTERN GraniteWidgetsTimePicker* granite_widgets_time_picker_new (void);
VALA_EXTERN GraniteWidgetsTimePicker* granite_widgets_time_picker_construct (GType object_type);
VALA_EXTERN GType granite_widgets_toast_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsToast, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_toast_get_title (GraniteWidgetsToast* self);
VALA_EXTERN void granite_widgets_toast_set_title (GraniteWidgetsToast* self,
                                      const gchar* value);
VALA_EXTERN GraniteWidgetsToast* granite_widgets_toast_new (const gchar* title);
VALA_EXTERN GraniteWidgetsToast* granite_widgets_toast_construct (GType object_type,
                                                      const gchar* title);
VALA_EXTERN void granite_widgets_toast_set_default_action (GraniteWidgetsToast* self,
                                               const gchar* label);
VALA_EXTERN void granite_widgets_toast_send_notification (GraniteWidgetsToast* self);
VALA_EXTERN GType granite_text_style_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* granite_text_style_get_stylesheet (GraniteTextStyle self,
                                          gchar** style_class);
VALA_EXTERN GType granite_close_button_position_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* granite_accel_to_string (const gchar* accel);
VALA_EXTERN gchar* granite_markup_accel_tooltip (gchar** accels,
                                     gint accels_length1,
                                     const gchar* description);
VALA_EXTERN void granite_contrasting_foreground_color (GdkRGBA* bg_color,
                                           GdkRGBA* result);
VALA_EXTERN GtkCssProvider* granite_widgets_utils_set_color_primary (GtkWidget* window,
                                                         GdkRGBA* color,
                                                         gint priority);
VALA_EXTERN GtkCssProvider* granite_widgets_utils_set_theming (GtkWidget* widget,
                                                   const gchar* stylesheet,
                                                   const gchar* class_name,
                                                   gint priority) G_GNUC_DEPRECATED ;
VALA_EXTERN GtkCssProvider* granite_widgets_utils_set_theming_for_screen (GdkScreen* screen,
                                                              const gchar* stylesheet,
                                                              gint priority) G_GNUC_DEPRECATED ;
VALA_EXTERN GtkCssProvider* granite_widgets_utils_get_css_provider (const gchar* stylesheet) G_GNUC_DEPRECATED ;
VALA_EXTERN void granite_widgets_utils_apply_text_style_to_label (GraniteTextStyle text_style,
                                                      GtkLabel* label) G_GNUC_DEPRECATED ;
VALA_EXTERN gboolean granite_widgets_utils_get_default_close_button_position (GraniteCloseButtonPosition* position) G_GNUC_DEPRECATED ;
VALA_EXTERN gchar* granite_widgets_utils_get_button_layout_schema (void) G_GNUC_DEPRECATED ;
VALA_EXTERN GType granite_validated_entry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteValidatedEntry, g_object_unref)
VALA_EXTERN gboolean granite_validated_entry_get_is_valid (GraniteValidatedEntry* self);
VALA_EXTERN void granite_validated_entry_set_is_valid (GraniteValidatedEntry* self,
                                           gboolean value);
VALA_EXTERN gint granite_validated_entry_get_min_length (GraniteValidatedEntry* self);
VALA_EXTERN void granite_validated_entry_set_min_length (GraniteValidatedEntry* self,
                                             gint value);
VALA_EXTERN GRegex* granite_validated_entry_get_regex (GraniteValidatedEntry* self);
VALA_EXTERN void granite_validated_entry_set_regex (GraniteValidatedEntry* self,
                                        GRegex* value);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_new_from_regex (GRegex* regex_arg);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_construct_from_regex (GType object_type,
                                                                     GRegex* regex_arg);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_new (void);
VALA_EXTERN GraniteValidatedEntry* granite_validated_entry_construct (GType object_type);
VALA_EXTERN GType granite_widgets_welcome_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsWelcomeButton, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_welcome_button_get_title (GraniteWidgetsWelcomeButton* self);
VALA_EXTERN void granite_widgets_welcome_button_set_title (GraniteWidgetsWelcomeButton* self,
                                               const gchar* value);
VALA_EXTERN const gchar* granite_widgets_welcome_button_get_description (GraniteWidgetsWelcomeButton* self);
VALA_EXTERN void granite_widgets_welcome_button_set_description (GraniteWidgetsWelcomeButton* self,
                                                     const gchar* value);
VALA_EXTERN GtkImage* granite_widgets_welcome_button_get_icon (GraniteWidgetsWelcomeButton* self);
VALA_EXTERN void granite_widgets_welcome_button_set_icon (GraniteWidgetsWelcomeButton* self,
                                              GtkImage* value);
VALA_EXTERN GraniteWidgetsWelcomeButton* granite_widgets_welcome_button_new (GtkImage* image,
                                                                 const gchar* option_text,
                                                                 const gchar* description_text);
VALA_EXTERN GraniteWidgetsWelcomeButton* granite_widgets_welcome_button_construct (GType object_type,
                                                                       GtkImage* image,
                                                                       const gchar* option_text,
                                                                       const gchar* description_text);
VALA_EXTERN GType granite_widgets_welcome_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraniteWidgetsWelcome, g_object_unref)
VALA_EXTERN const gchar* granite_widgets_welcome_get_title (GraniteWidgetsWelcome* self);
VALA_EXTERN void granite_widgets_welcome_set_title (GraniteWidgetsWelcome* self,
                                        const gchar* value);
VALA_EXTERN const gchar* granite_widgets_welcome_get_subtitle (GraniteWidgetsWelcome* self);
VALA_EXTERN void granite_widgets_welcome_set_subtitle (GraniteWidgetsWelcome* self,
                                           const gchar* value);
VALA_EXTERN GraniteWidgetsWelcome* granite_widgets_welcome_new (const gchar* title_text,
                                                    const gchar* subtitle_text);
VALA_EXTERN GraniteWidgetsWelcome* granite_widgets_welcome_construct (GType object_type,
                                                          const gchar* title_text,
                                                          const gchar* subtitle_text);
VALA_EXTERN void granite_widgets_welcome_set_item_visible (GraniteWidgetsWelcome* self,
                                               guint index,
                                               gboolean val);
VALA_EXTERN void granite_widgets_welcome_remove_item (GraniteWidgetsWelcome* self,
                                          guint index);
VALA_EXTERN void granite_widgets_welcome_set_item_sensitivity (GraniteWidgetsWelcome* self,
                                                   guint index,
                                                   gboolean val);
VALA_EXTERN gint granite_widgets_welcome_append (GraniteWidgetsWelcome* self,
                                     const gchar* icon_name,
                                     const gchar* option_text,
                                     const gchar* description_text);
VALA_EXTERN gint granite_widgets_welcome_append_with_pixbuf (GraniteWidgetsWelcome* self,
                                                 GdkPixbuf* pixbuf,
                                                 const gchar* option_text,
                                                 const gchar* description_text);
VALA_EXTERN gint granite_widgets_welcome_append_with_image (GraniteWidgetsWelcome* self,
                                                GtkImage* image,
                                                const gchar* option_text,
                                                const gchar* description_text);
VALA_EXTERN GraniteWidgetsWelcomeButton* granite_widgets_welcome_get_button_from_index (GraniteWidgetsWelcome* self,
                                                                            gint index);

VALA_EXTERN const GOptionEntry GRANITE_APPLICATION_options[2];

G_END_DECLS

#endif
